@@ -8,13 +8,14 @@
 
 
 /* Datastorage and Permissions */
+$conf['fmode']       = 0644;              //set file creation mode
+$conf['dmode']       = 0755;              //set directory creation mode
 
-$conf['umask']       = 0111;              //set the umask for new files
-$conf['dmask']       = 0000;              //directory mask accordingly
 $conf['lang']        = 'en';              //your language
 $conf['basedir']     = '';                //absolute dir from serveroot - blank for autodetection
 $conf['baseurl']     = '';                //URL to server including protocol - blank for autodetect
 $conf['savedir']     = './data';          //where to store all the files
+$conf['allowdebug']  = 1;                 //make debug possible, disable after install! 0|1
 
 /* Display Options */
 
@@ -24,6 +25,7 @@ $conf['template']    = 'default';         //see tpl directory
 $conf['fullpath']    = 0;                 //show full path of the document or relative to datadir only? 0|1
 $conf['recent']      = 20;                //how many entries to show in recent
 $conf['breadcrumbs'] = 10;                //how many recent visited pages to show
+$conf['youarehere']  = 0;                 //show "You are here" navigation? 0|1
 $conf['typography']  = 1;                 //convert quotes, dashes and stuff to typographic equivalents? 0|1
 $conf['htmlok']      = 0;                 //may raw HTML be embedded? This may break layout and XHTML validity 0|1
 $conf['phpok']       = 0;                 //may PHP code be embedded? Never do this on the internet! 0|1
@@ -33,7 +35,7 @@ $conf['toptoclevel'] = 1;                 //Level starting with and below to inc
 $conf['maxtoclevel'] = 3;                 //Up to which level include into AutoTOC (max. 5)
 $conf['maxseclevel'] = 3;                 //Up to which level create editable sections (max. 5)
 $conf['camelcase']   = 0;                 //Use CamelCase for linking? (I don't like it) 0|1
-$conf['deaccent']    = 1;                 //convert accented chars to unaccented ones in pagenames?
+$conf['deaccent']    = 1;                 //deaccented chars in pagenames (1) or romanize (2) or keep (0)?
 $conf['useheading']  = 0;                 //use the first heading in a page as its name
 $conf['refcheck']    = 1;                 //check for references before deleting media files
 $conf['refshow']     = 0;                 //how many references should be shown, 5 is a good value
@@ -53,10 +55,12 @@ $conf['mailguard']   = 'hex';             //obfuscate email addresses against sp
 $conf['useacl']      = 0;                //Use Access Control Lists to restrict access?
 $conf['openregister']= 1;                //Should users to be allowed to register?
 $conf['autopasswd']  = 1;                //autogenerate passwords and email them to user
+$conf['resendpasswd']= 0;                //allow resend password function?
 $conf['authtype']    = 'plain';          //which authentication backend should be used
 $conf['passcrypt']   = 'smd5';           //Used crypt method (smd5,md5,sha1,ssha,crypt,mysql,my411)
 $conf['defaultgroup']= 'user';           //Default groups new Users are added to
 $conf['superuser']   = '!!not set!!';    //The admin can be user or @group
+$conf['profileconfirm'] = '1';           //Require current password to confirm changes to user profile
 
 /* Advanced Options */
 $conf['userewrite']  = 0;                //this makes nice URLs: 0: off 1: .htaccess 2: internal
@@ -75,7 +79,10 @@ $conf['gdlib']       = 2;                //the GDlib version (0, 1 or 2) 2 tries
 $conf['im_convert']  = '';               //path to ImageMagicks convert (will be used instead of GD)
 $conf['spellchecker']= 0;                //enable Spellchecker (needs PHP >= 4.3.0 and aspell installed)
 $conf['subscribers'] = 0;                //enable change notice subscription support
-$conf['pluginmanager'] = 0;              //enable automated plugin management (requires plugin)
+$conf['compress']    = 1;                //Strip whitespaces and comments from Styles and JavaScript? 1|0
+$conf['hidepages']   = '';               //Regexp for pages to be skipped from RSS, Search and Recent Changes
+$conf['send404']     = 0;                //Send a HTTP 404 status for non existing pages?
+$conf['sitemap']     = 0;                //Create a google sitemap? How often? In days.
 $conf['rss_type']    = 'rss1';           //type of RSS feed to provide, by default:
                                          //  'rss'  - RSS 0.91
                                          //  'rss1' - RSS 1.0
@@ -89,8 +96,8 @@ $conf['rss_linkto'] = 'diff';            //what page RSS entries link to:
 
 //Set target to use when creating links - leave empty for same window
 $conf['target']['wiki']      = '';
-$conf['target']['interwiki'] = '_blank';
-$conf['target']['extern']    = '_blank';
+$conf['target']['interwiki'] = '';
+$conf['target']['extern']    = '';
 $conf['target']['media']     = '';
 $conf['target']['windows']   = '';
 
