@@ -26,7 +26,7 @@
   $RANGE = $_REQUEST['lines'];
   $HIGH  = $_REQUEST['s'];
   if(empty($HIGH)) $HIGH = getGoogleQuery();
-  
+
   $TEXT  = cleanText($_POST['wikitext']);
   $PRE   = cleanText($_POST['prefix']);
   $SUF   = cleanText($_POST['suffix']);
@@ -45,14 +45,19 @@
   if(empty($ACT)) $ACT = 'show';
 
 
-  if($ACT == 'debug'){
+  if($conf['allowdebug'] && $ACT == 'debug'){
     html_debug();
     exit;
   }
-  
+
   //make infos about the selected page available
   $INFO = pageinfo();
 
+  //send 404 for missing pages if configured
+  if($conf['send404'] && !$INFO['exists']){
+    header('HTTP/1.0 404 Not Found');
+  }
+
   //prepare breadcrumbs (initialize a static var)
   breadcrumbs();
 
@@ -62,8 +67,5 @@
   //do the work
   act_dispatch($ACT);
 
-  //restore old umask
-  umask($conf['oldumask']);
-
 //  xdebug_dump_function_profile(1);
 ?>
