@@ -20,6 +20,7 @@
   $num   = $_REQUEST['num'];
   $type  = $_REQUEST['type'];
   $mode  = $_REQUEST['mode'];
+  $minor = $_REQUEST['minor'];
   $ns    = $_REQUEST['ns'];
   $ltype = $_REQUEST['linkto'];
 
@@ -40,20 +41,20 @@
        $type = 'RSS1.0';
   }
 
-	// the feed is dynamic - we need a cache for each combo
+  // the feed is dynamic - we need a cache for each combo
   // (but most people just use the default feed so it's still effective)
-	$cache = getCacheName($num.$type.$mode.$ns.$ltype.$_SERVER['REMOTE_USER'],'.feed');
+  $cache = getCacheName($num.$type.$mode.$ns.$ltype.$_SERVER['REMOTE_USER'],'.feed');
 
-	// check cacheage and deliver if nothing has changed since last
+  // check cacheage and deliver if nothing has changed since last
   // time (with 5 minutes settletime)
-	$cmod = @filemtime($cache); // 0 if not exists
-	if($cmod && ($cmod+(5*60) >= @filemtime($conf['changelog']))){
-  	header('Content-Type: application/xml; charset=utf-8');
-		print io_readFile($cache);
-		exit;
+  $cmod = @filemtime($cache); // 0 if not exists
+  if($cmod && ($cmod+(5*60) >= @filemtime($conf['changelog']))){
+    header('Content-Type: application/xml; charset=utf-8');
+    print io_readFile($cache);
+    exit;
   }
 
-	// create new feed
+  // create new feed
   $rss = new DokuWikiFeedCreator();
   $rss->title = $conf['title'].(($ns) ? ' '.$ns : '');
   $rss->link  = DOKU_URL;
@@ -69,15 +70,15 @@
   if($mode == 'list'){
     rssListNamespace($rss,$ns);
   }else{
-    rssRecentChanges($rss,$num,$ltype,$ns);
+    rssRecentChanges($rss,$num,$ltype,$ns,$minor);
   }
 
   $feed = $rss->createFeed($type,'utf-8');
-	
-  // save cachefile
-	io_saveFile($cache,$feed);
 
-	// finally deliver
+  // save cachefile
+  io_saveFile($cache,$feed);
+
+  // finally deliver
   header('Content-Type: application/xml; charset=utf-8');
   print $feed;
 
@@ -88,22 +89,28 @@
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function rssRecentChanges(&$rss,$num,$ltype,$ns){
+function rssRecentChanges(&$rss,$num,$ltype,$ns,$minor){
   global $conf;
+  global $auth;
+
   if(!$num) $num = $conf['recent'];
   $guardmail = ($conf['mailguard'] != '' && $conf['mailguard'] != 'none');
 
-  $recents = getRecents(0,$num,false,$ns);
+
+  $flags = RECENTS_SKIP_DELETED;
+  if(!$minor) $flags += RECENTS_SKIP_MINORS;
+
+  $recents = getRecents(0,$num,$ns,$flags);
 
   //this can take some time if a lot of recaching has to be done
   @set_time_limit(90); // set max execution time
 
-	foreach($recents as $recent){
+  foreach($recents as $recent){
 
     $item = new FeedItem();
     $item->title = $recent['id'];
     $xhtml = p_wiki_xhtml($recent['id'],'',false);
-    
+
     if($conf['useheading']) {
         $matches = array();
         if(preg_match('|<h([1-9])>(.*?)</h\1>|', $xhtml, $matches))
@@ -123,27 +130,27 @@ function rssRecentChanges(&$rss,$num,$ltype,$ns){
         $item->link = wl($recent['id'],'rev='.$recent['date'],true);
         break;
       case 'rev':
-        $item->link = wl($recent['id'],'do=revisions&amp;rev='.$recent['date'],true);
+        $item->link = wl($recent['id'],'do=revisions&rev='.$recent['date'],true);
         break;
       case 'current':
         $item->link = wl($recent['id'], '', true);
         break;
       case 'diff':
       default:
-        $item->link = wl($recent['id'],'do=diff&amp;'.$recent['date'],true);
+        $item->link = wl($recent['id'],'do=diff'.$recent['date'],true);
     }
 
     $item->description = $desc;
     $item->date        = date('r',$recent['date']);
-		$cat = getNS($recent['id']);
-		if($cat) $item->category = $cat;
-    
+    $cat = getNS($recent['id']);
+    if($cat) $item->category = $cat;
+
     $user = null;
     $user = @$recent['user']; // the @ spares time repeating lookup
     $item->author = '';
-    
+
     if($user){
-      $userInfo = auth_getUserData($user);
+      $userInfo = $auth->getUserData($user);
       $item->author = $userInfo['name'];
       if($guardmail) {
         //cannot obfuscate because some RSS readers may check validity
@@ -174,16 +181,25 @@ function rssListNamespace(&$rss,$ns){
   sort($data);
   search($data,$conf['datadir'],'search_list','',$ns);
   foreach($data as $row){
-    $id = $row['id'];
-    $date = filemtime(wikiFN($id));
-    $desc = cleanDesc(p_wiki_xhtml($id,'',false));
     $item = new FeedItem();
+
+    $id    = $row['id'];
+    $date  = filemtime(wikiFN($id));
+    $xhtml = p_wiki_xhtml($id,'',false);
+    $desc  = cleanDesc($xhtml);
     $item->title       = $id;
+
+    if($conf['useheading']) {
+        $matches = array();
+        if(preg_match('|<h([1-9])>(.*?)</h\1>|', $xhtml, $matches))
+            $item->title = trim($matches[2]);
+    }
+
     $item->link        = wl($id,'rev='.$date,true);
     $item->description = $desc;
     $item->date        = date('r',$date);
     $rss->addItem($item);
-  }  
+  }
 }
 
 /**
