@@ -12,10 +12,33 @@
   if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__).'/../').'/');
   require_once(DOKU_INC.'inc/common.php');
   require_once(DOKU_INC.'inc/io.php');
-  require_once(DOKU_INC.'inc/blowfish.php');
-  require_once(DOKU_INC.'inc/mail.php');
-  // load the the auth functions
-  require_once(DOKU_INC.'inc/auth/'.$conf['authtype'].'.php');
+
+  if($conf['useacl']){
+    require_once(DOKU_INC.'inc/blowfish.php');
+    require_once(DOKU_INC.'inc/mail.php');
+
+    // load the the backend auth functions and instantiate the auth object
+    if (@file_exists(DOKU_INC.'inc/auth/'.$conf['authtype'].'.class.php')) {
+      require_once(DOKU_INC.'inc/auth/basic.class.php');
+      require_once(DOKU_INC.'inc/auth/'.$conf['authtype'].'.class.php');
+
+      $auth_class = "auth_".$conf['authtype'];
+      if (class_exists($auth_class)) {
+        $auth = new $auth_class();
+        if ($auth->success == false) {
+          unset($auth);
+          msg($lang['authtempfail'], -1);
+
+          // turn acl config setting off for the rest of this page
+          $conf['useacl'] = 0;
+        }
+      } else {
+        nice_die($lang['authmodfailed']);
+      }
+    } else {
+      nice_die($lang['authmodfailed']);
+    }
+  }
 
   if (!defined('DOKU_COOKIE')) define('DOKU_COOKIE', 'DW'.md5($conf['title']));
 
@@ -28,8 +51,15 @@
   define('AUTH_DELETE',16);
   define('AUTH_ADMIN',255);
 
+  // do the login either by cookie or provided credentials
   if($conf['useacl']){
-    auth_login($_REQUEST['u'],$_REQUEST['p'],$_REQUEST['r']);
+    // external trust mechanism in place?
+    if(!is_null($auth) && $auth->canDo('external')){
+      $auth->trustExternal($_REQUEST['u'],$_REQUEST['p'],$_REQUEST['r']);
+    }else{
+      auth_login($_REQUEST['u'],$_REQUEST['p'],$_REQUEST['r']);
+    }
+
     //load ACL into a global array
     if(is_readable(DOKU_CONF.'acl.auth.php')){
       $AUTH_ACL = file(DOKU_CONF.'acl.auth.php');
@@ -70,14 +100,15 @@ function auth_login($user,$pass,$sticky=false){
   global $USERINFO;
   global $conf;
   global $lang;
+  global $auth;
   $sticky ? $sticky = true : $sticky = false; //sanity check
 
   if(isset($user)){
     //usual login
-    if (auth_checkPass($user,$pass)){
+    if ($auth->checkPass($user,$pass)){
       // make logininfo globally available
       $_SERVER['REMOTE_USER'] = $user;
-      $USERINFO = auth_getUserData($user); //FIXME move all references to session 
+      $USERINFO = $auth->getUserData($user); //FIXME move all references to session
 
       // set cookie
       $pass   = PMA_blowfish_encrypt($pass,auth_cookiesalt());
@@ -178,6 +209,8 @@ function auth_cookiesalt(){
 function auth_logoff(){
   global $conf;
   global $USERINFO;
+  global $INFO, $ID;
+  global $auth;
 
   if(isset($_SESSION[$conf['title']]['auth']['user']))
     unset($_SESSION[$conf['title']]['auth']['user']);
@@ -189,6 +222,10 @@ function auth_logoff(){
     unset($_SERVER['REMOTE_USER']);
   $USERINFO=null; //FIXME
   setcookie(DOKU_COOKIE,'',time()-600000,'/');
+
+  if($auth && $auth->canDo('logoff')){
+    $auth->logOff();
+  }
 }
 
 /**
@@ -226,20 +263,22 @@ function auth_aclcheck($id,$user,$groups){
 
   # if no ACL is used always return upload rights
   if(!$conf['useacl']) return AUTH_UPLOAD;
-  
+
+  $user = auth_nameencode($user);
+
   //if user is superuser return 255 (acl_admin)
-  if($conf['superuser'] == $user) { return AUTH_ADMIN; }
+  if(auth_nameencode($conf['superuser']) == $user) { return AUTH_ADMIN; }
 
   //make sure groups is an array
   if(!is_array($groups)) $groups = array();
 
-  //prepend groups with @
+  //prepend groups with @ and nameencode
   $cnt = count($groups);
   for($i=0; $i<$cnt; $i++){
-    $groups[$i] = '@'.$groups[$i];
+    $groups[$i] = '@'.auth_nameencode($groups[$i]);
   }
   //if user is in superuser group return 255 (acl_admin)
-  if(in_array($conf['superuser'], $groups)) { return AUTH_ADMIN; }
+  if(in_array(auth_nameencode($conf['superuser'],true), $groups)) { return AUTH_ADMIN; }
 
   $ns    = getNS($id);
   $perm  = -1;
@@ -256,7 +295,7 @@ function auth_aclcheck($id,$user,$groups){
   }
 
   //check exact match first
-  $matches = preg_grep('/^'.$id.'\s+('.$regexp.')\s+/',$AUTH_ACL);
+  $matches = preg_grep('/^'.preg_quote($id,'/').'\s+('.$regexp.')\s+/',$AUTH_ACL);
   if(count($matches)){
     foreach($matches as $match){
       $match = preg_replace('/#.*$/','',$match); //ignore comments
@@ -313,6 +352,29 @@ function auth_aclcheck($id,$user,$groups){
   return AUTH_NONE;
 }
 
+/**
+ * Encode ASCII special chars
+ *
+ * Some auth backends allow special chars in their user and groupnames
+ * The special chars are encoded with this function. Only ASCII chars
+ * are encoded UTF-8 multibyte are left as is (different from usual
+ * urlencoding!).
+ *
+ * Decoding can be done with rawurldecode
+ *
+ * @author Andreas Gohr <gohr@cosmocode.de>
+ * @see rawurldecode()
+ */
+function auth_nameencode($name,$skip_group=false){
+  if($skip_group && $name{0} =='@'){
+    return '@'.preg_replace('/([\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f])/e',
+                            "'%'.dechex(ord('\\1'))",substr($name,1));
+  }else{
+    return preg_replace('/([\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f])/e',
+                        "'%'.dechex(ord('\\1'))",$name);
+  }
+}
+
 /**
  * Create a pronouncable password
  *
@@ -349,8 +411,10 @@ function auth_pwgen(){
 function auth_sendPassword($user,$password){
   global $conf;
   global $lang;
+  global $auth;
+
   $hdrs  = '';
-  $userinfo = auth_getUserData($user);
+  $userinfo = $auth->getUserData($user);
 
   if(!$userinfo['mail']) return false;
 
@@ -369,7 +433,7 @@ function auth_sendPassword($user,$password){
 
 /**
  * Register a new user
- * 
+ *
  * This registers a new user - Data is read directly from $_POST
  *
  * @author  Andreas Gohr <andi@splitbrain.org>
@@ -379,8 +443,10 @@ function auth_sendPassword($user,$password){
 function register(){
   global $lang;
   global $conf;
+  global $auth;
 
   if(!$_POST['save']) return false;
+  if(!$auth->canDo('addUser')) return false;
 
   //clean username
   $_POST['login'] = preg_replace('/.*:/','',$_POST['login']);
@@ -416,8 +482,7 @@ function register(){
   }
 
   //okay try to create the user
-  $pass = auth_createUser($_POST['login'],$pass,$_POST['fullname'],$_POST['email']);
-  if(empty($pass)){
+  if(!$auth->createUser($_POST['login'],$pass,$_POST['fullname'],$_POST['email'])){
     msg($lang['reguexists'],-1);
     return false;
   }
@@ -437,11 +502,117 @@ function register(){
   }
 }
 
+/**
+ * Update user profile
+ *
+ * @author    Christopher Smith <chris@jalakai.co.uk>
+ */
+function updateprofile() {
+  global $conf;
+  global $INFO;
+  global $lang;
+  global $auth;
+
+  if(!$_POST['save']) return false;
+
+  // should not be able to get here without Profile being possible...
+  if(!$auth->canDo('Profile')) {
+    msg($lang['profna'],-1);
+    return false;
+  }
+
+  if ($_POST['newpass'] != $_POST['passchk']) {
+    msg($lang['regbadpass'], -1);      // complain about misspelled passwords
+    return false;
+  }
+
+  //clean fullname and email
+  $_POST['fullname'] = trim(str_replace(':','',$_POST['fullname']));
+  $_POST['email']    = trim(str_replace(':','',$_POST['email']));
+
+  if (empty($_POST['fullname']) || empty($_POST['email'])) {
+    msg($lang['profnoempty'],-1);
+    return false;
+  }
+
+  if (!mail_isvalid($_POST['email'])){
+    msg($lang['regbadmail'],-1);
+    return false;
+  }
+
+  if ($_POST['fullname'] != $INFO['userinfo']['name']) $changes['name'] = $_POST['fullname'];
+  if ($_POST['email']    != $INFO['userinfo']['mail']) $changes['mail'] = $_POST['email'];
+  if (!empty($_POST['newpass']))  $changes['pass'] = $_POST['newpass'];
+
+  if (!count($changes)) {
+    msg($lang['profnochange'], -1);
+    return false;
+  }
+
+  if ($conf['profileconfirm']) {
+      if (!auth_verifyPassword($_POST['oldpass'],$INFO['userinfo']['pass'])) {
+      msg($lang['badlogin'],-1);
+      return false;
+    }
+  }
+
+  return $auth->modifyUser($_SERVER['REMOTE_USER'], $changes);
+}
+
+/**
+ * Send a  new password
+ *
+ * @author Benoit Chesneau <benoit@bchesneau.info>
+ * @author Chris Smith <chris@jalakai.co.uk>
+ *
+ * @return bool true on success, false on any error
+*/
+function act_resendpwd(){
+    global $lang;
+    global $conf;
+    global $auth;
+
+    if(!$_POST['save']) return false;
+    if(!$conf['resendpasswd']) return false;
+
+    // should not be able to get here without modPass being possible...
+    if(!$auth->canDo('modPass')) {
+      msg($lang['resendna'],-1);
+      return false;
+    }
+
+    if (empty($_POST['login'])) {
+      msg($lang['resendpwdmissing'], -1);
+      return false;
+    } else {
+      $user = $_POST['login'];
+    }
+
+    $userinfo = $auth->getUserData($user);
+    if(!$userinfo['mail']) {
+      msg($lang['resendpwdnouser'], -1);
+      return false;
+    }
+
+    $pass = auth_pwgen();
+    if (!$auth->modifyUser($user,array('pass' => $pass))) {
+      msg('error modifying user data',-1);
+      return false;
+    }
+
+    if (auth_sendPassword($user,$pass)) {
+      msg($lang['resendpwdsuccess'],1);
+    } else {
+      msg($lang['regmailfail'],-1);
+    }
+    return true;
+}
+
 /**
  * Uses a regular expresion to check if a given mail address is valid
  *
  * May not be completly RFC conform!
- * 
+ *
  * @link    http://www.webmasterworld.com/forum88/135.htm
  *
  * @param   string $email the address to check
