@@ -13,6 +13,13 @@
   require_once(DOKU_INC.'inc/mail.php');
   require_once(DOKU_INC.'inc/parserutils.php');
 
+/**
+ * These constants are used with the recents function
+ */
+define('RECENTS_SKIP_DELETED',2);
+define('RECENTS_SKIP_MINORS',4);
+define('RECENTS_SKIP_SUBSPACES',8);
+
 /**
  * Return info about the current document as associative
  * array.
@@ -29,6 +36,11 @@ function pageinfo(){
     $info['userinfo']   = $USERINFO;
     $info['perm']       = auth_quickaclcheck($ID);
     $info['subscribed'] = is_subscribed($ID,$_SERVER['REMOTE_USER']);
+
+    // if some outside auth were used only REMOTE_USER is set
+    if(!$info['userinfo']['name']){
+      $info['userinfo']['name'] = $_SERVER['REMOTE_USER'];
+    }
   }else{
     $info['perm']       = auth_aclcheck($ID,'',null);
     $info['subscribed'] = false;
@@ -66,6 +78,7 @@ function pageinfo(){
   $info['ip']     = $revinfo['ip'];
   $info['user']   = $revinfo['user'];
   $info['sum']    = $revinfo['sum'];
+  $info['minor']  = $revinfo['minor'];
 
   if($revinfo['user']){
     $info['editor'] = $revinfo['user'];
@@ -81,14 +94,14 @@ function pageinfo(){
  *
  * @author Andreas Gohr
  */
-function buildURLparams($params){
+function buildURLparams($params, $sep='&amp;'){
   $url = '';
   $amp = false;
   foreach($params as $key => $val){
-    if($amp) $url .= '&amp;';
+    if($amp) $url .= $sep;
 
     $url .= $key.'=';
-    $url .= urlencode($val);
+    $url .= rawurlencode($val);
     $amp = true;
   }
   return $url;
@@ -113,10 +126,10 @@ function buildAttributes($params){
 /**
  * print a message
  *
- * If HTTP headers were not sent yet the message is added 
+ * If HTTP headers were not sent yet the message is added
  * to the global message array else it's printed directly
  * using html_msgarea()
- * 
+ *
  *
  * Levels can be:
  *
@@ -127,12 +140,14 @@ function buildAttributes($params){
  * @author Andreas Gohr <andi@splitbrain.org>
  * @see    html_msgarea
  */
-function msg($message,$lvl=0){
+function msg($message,$lvl=0,$line='',$file=''){
   global $MSG;
   $errors[-1] = 'error';
   $errors[0]  = 'info';
   $errors[1]  = 'success';
 
+  if($line || $file) $message.=' ['.basename($file).':'.$line.']';
+
   if(!headers_sent()){
     if(!isset($MSG)) $MSG = array();
     $MSG[]=array('lvl' => $errors[$lvl], 'msg' => $message);
@@ -161,7 +176,7 @@ function breadcrumbs(){
   global $ACT;
   global $conf;
   $crumbs = $_SESSION[$conf['title']]['bc'];
-  
+
   //first visit?
   if (!is_array($crumbs)){
     $crumbs = array();
@@ -219,7 +234,7 @@ function idfilter($id,$ue=true){
     $id = strtr($id,':',';');
   }
   if($ue){
-    $id = urlencode($id);
+    $id = rawurlencode($id);
     $id = str_replace('%3A',':',$id); //keep as colon
     $id = str_replace('%2F','/',$id); //keep as slash
   }
@@ -234,12 +249,12 @@ function idfilter($id,$ue=true){
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function wl($id='',$more='',$abs=false){
+function wl($id='',$more='',$abs=false,$sep='&amp;'){
   global $conf;
   if(is_array($more)){
-    $more = buildURLparams($more);
+    $more = buildURLparams($more,$sep);
   }else{
-    $more = str_replace(',','&amp;',$more);
+    $more = str_replace(',',$sep,$more);
   }
 
   $id    = idfilter($id);
@@ -257,9 +272,9 @@ function wl($id='',$more='',$abs=false){
     if($more) $xlink .= '?'.$more;
   }else{
     $xlink .= DOKU_SCRIPT.'?id='.$id;
-    if($more) $xlink .= '&amp;'.$more;
+    if($more) $xlink .= $sep.$more;
   }
-  
+
   return $xlink;
 }
 
@@ -268,12 +283,12 @@ function wl($id='',$more='',$abs=false){
  *
  * Will return a link to the detail page if $direct is false
  */
-function ml($id='',$more='',$direct=true){
+function ml($id='',$more='',$direct=true,$sep='&amp;'){
   global $conf;
   if(is_array($more)){
-    $more = buildURLparams($more);
+    $more = buildURLparams($more,$sep);
   }else{
-    $more = str_replace(',','&amp;',$more);
+    $more = str_replace(',',$sep,$more);
   }
 
   $xlink = DOKU_BASE;
@@ -283,12 +298,12 @@ function ml($id='',$more='',$direct=true){
     $xlink .= 'lib/exe/fetch.php';
     if($more){
       $xlink .= '?'.$more;
-      $xlink .= '&amp;media='.urlencode($id);
+      $xlink .= $sep.'media='.rawurlencode($id);
     }else{
-      $xlink .= '?media='.urlencode($id);
+      $xlink .= '?media='.rawurlencode($id);
     }
     return $xlink;
-  } 
+  }
 
   $id = idfilter($id);
 
@@ -314,7 +329,7 @@ function ml($id='',$more='',$direct=true){
    }else{
      if($more){
        $xlink .= $script.'?'.$more;
-       $xlink .= '&amp;media='.$id;
+       $xlink .= $sep.'media='.$id;
      }else{
        $xlink .= $script.'?media='.$id;
      }
@@ -352,19 +367,19 @@ function checkwordblock(){
 
   if(!$conf['usewordblock']) return false;
 
-  $blockfile = file(DOKU_CONF.'wordblock.conf');
+  $wordblocks = getWordblocks();
   //how many lines to read at once (to work around some PCRE limits)
   if(version_compare(phpversion(),'4.3.0','<')){
     //old versions of PCRE define a maximum of parenthesises even if no
     //backreferences are used - the maximum is 99
     //this is very bad performancewise and may even be too high still
-    $chunksize = 40; 
+    $chunksize = 40;
   }else{
     //read file in chunks of 600 - this should work around the
     //MAX_PATTERN_SIZE in modern PCRE
-    $chunksize = 600;
+    $chunksize = 400;
   }
-  while($blocks = array_splice($blockfile,0,$chunksize)){
+  while($blocks = array_splice($wordblocks,0,$chunksize)){
     $re = array();
     #build regexp from blocks
     foreach($blocks as $block){
@@ -373,7 +388,9 @@ function checkwordblock(){
       if(empty($block)) continue;
       $re[]  = $block;
     }
-    if(preg_match('#('.join('|',$re).')#si',$TEXT)) return true;
+    if(preg_match('#('.join('|',$re).')#si',$TEXT, $match=array())) {
+      return true;
+    }
   }
   return false;
 }
@@ -403,22 +420,22 @@ function clientIP(){
 function checklock($id){
   global $conf;
   $lock = wikiFN($id).'.lock';
-  
+
   //no lockfile
   if(!@file_exists($lock)) return false;
-  
+
   //lockfile expired
   if((time() - filemtime($lock)) > $conf['locktime']){
     unlink($lock);
     return false;
   }
-  
+
   //my own lock
   $ip = io_readFile($lock);
   if( ($ip == clientIP()) || ($ip == $_SERVER['REMOTE_USER']) ){
     return false;
   }
-  
+
   return $ip;
 }
 
@@ -468,7 +485,7 @@ function cleanText($text){
 /**
  * Prepares text for print in Webforms by encoding special chars.
  * It also converts line endings to Windows format which is
- * pseudo standard for webforms. 
+ * pseudo standard for webforms.
  *
  * @see    cleanText() for 2unix conversion
  * @author Andreas Gohr <andi@splitbrain.org>
@@ -578,7 +595,7 @@ function dbg($msg,$hidden=false){
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function addLogEntry($date,$id,$summary=""){
+function addLogEntry($date,$id,$summary='',$minor=false){
   global $conf;
 
   if(!@is_writable($conf['changelog'])){
@@ -590,10 +607,32 @@ function addLogEntry($date,$id,$summary=""){
   $remote = $_SERVER['REMOTE_ADDR'];
   $user   = $_SERVER['REMOTE_USER'];
 
+  if($conf['useacl'] && $user && $minor){
+    $summary = '*'.$summary;
+  }else{
+    $summary = ' '.$summary;
+  }
+
   $logline = join("\t",array($date,$remote,$id,$user,$summary))."\n";
   io_saveFile($conf['changelog'],$logline,true);
 }
 
+/**
+ * Checks an summary entry if it was a minor edit
+ *
+ * The summary is cleaned of the marker char
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+function isMinor(&$summary){
+  if(substr($summary,0,1) == '*'){
+    $summary = substr($summary,1);
+    return true;
+  }
+  $summary = trim($summary);
+  return false;
+}
+
 /**
  * Internal function used by getRecents
  *
@@ -602,35 +641,49 @@ function addLogEntry($date,$id,$summary=""){
  * @see getRecents()
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function _handleRecent($line,$incdel,$ns,$subNS){
+function _handleRecent($line,$ns,$flags){
   static $seen  = array();         //caches seen pages and skip them
   if(empty($line)) return false;   //skip empty lines
 
   // split the line into parts
   list($dt,$ip,$id,$usr,$sum) = explode("\t",$line);
-  
+
   // skip seen ones
   if($seen[$id]) return false;
+  $recent = array();
+
+  // check minors
+  if(isMinor($sum)){
+    // skip minors
+    if($flags & RECENTS_SKIP_MINORS) return false;
+    $recent['minor'] = true;
+  }else{
+    $recent['minor'] = false;
+  }
 
   // remember in seen to skip additional sights
   $seen[$id] = 1;
 
+  // check if it's a hidden page
+  if(isHiddenPage($id)) return false;
+
   // filter namespace
   if (($ns) && (strpos($id,$ns.':') !== 0)) return false;
 
   // exclude subnamespaces
-  if ((!$subNS) && (getNS($id) != $ns)) return false;
+  if (($flags & RECENTS_SKIP_SUBSPACES) && (getNS($id) != $ns)) return false;
+
+  // check ACL
+  if (auth_quickaclcheck($id) < AUTH_READ) return false;
 
   // check existance
   if(!@file_exists(wikiFN($id))){
-    if(!$incdel){
+    if($flags & RECENTS_SKIP_DELETED){
       return false;
     }else{
-      $recent = array();
       $recent['del'] = true;
     }
   }else{
-    $recent = array();
     $recent['del'] = false;
   }
 
@@ -643,19 +696,26 @@ function _handleRecent($line,$incdel,$ns,$subNS){
   return $recent;
 }
 
+
 /**
  * returns an array of recently changed files using the
  * changelog
  *
+ * The following constants can be used to control which changes are
+ * included. Add them together as needed.
+ *
+ * RECENTS_SKIP_DELETED   - don't include deleted pages
+ * RECENTS_SKIP_MINORS    - don't include minor changes
+ * RECENTS_SKIP_SUBSPACES - don't include subspaces
+ *
  * @param int    $first   number of first entry returned (for paginating
  * @param int    $num     return $num entries
- * @param bool   $incdel  include deleted pages?
  * @param string $ns      restrict to given namespace
- * @param bool   $subNS   include subnamespaces
+ * @param bool   $flags   see above
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function getRecents($first,$num,$incdel=false,$ns='',$subNS=true){
+function getRecents($first,$num,$ns='',$flags=0){
   global $conf;
   $recent = array();
   $count  = 0;
@@ -677,7 +737,11 @@ function getRecents($first,$num,$incdel=false,$ns='',$subNS=true){
   // now read backwards into buffer
   while($pos > 0){
     $pos -= $csz;                           // seek to previous chunk...
-    if($pos < 0) $pos = 0;                  // ...or rest of file
+    if($pos < 0) {                          // ...or rest of file
+      $csz += $pos;
+      $pos = 0;
+    }
+
     fseek($fh,$pos);
 
     $buf = fread($fh,$csz).$buf;            // prepend to buffer
@@ -693,7 +757,7 @@ function getRecents($first,$num,$incdel=false,$ns='',$subNS=true){
 
     // handle lines
     for($i = $cnt-1; $i >= 0; $i--){
-      $rec = _handleRecent($lines[$i],$incdel,$ns,$subNS);
+      $rec = _handleRecent($lines[$i],$ns,$flags);
       if($rec !== false){
         if(--$first >= 0) continue;         // skip first entries
         $recent[] = $rec;
@@ -732,10 +796,11 @@ function getRevisionInfo($id,$rev){
   $loglines = preg_grep("/$rev\t\d+\.\d+\.\d+\.\d+\t$id\t/",$loglines);
   $loglines = array_reverse($loglines); //reverse sort on timestamp (shouldn't be needed)
   $line = split("\t",$loglines[0]);
-  $info['date'] = $line[0];
-  $info['ip']   = $line[1];
-  $info['user'] = $line[3];
+  $info['date']  = $line[0];
+  $info['ip']    = $line[1];
+  $info['user']  = $line[3];
   $info['sum']   = $line[4];
+  $info['minor'] = isMinor($info['sum']);
   return $info;
 }
 
@@ -744,10 +809,9 @@ function getRevisionInfo($id,$rev){
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function saveWikiText($id,$text,$summary){
+function saveWikiText($id,$text,$summary,$minor=false){
   global $conf;
   global $lang;
-  umask($conf['umask']);
   // ignore if no changes were made
   if($text == rawWiki($id,'')){
     return;
@@ -765,9 +829,11 @@ function saveWikiText($id,$text,$summary){
       if (file_exists($mfile)) @unlink($mfile);
     }
     $del = true;
-    //autoset summary on deletion
+    // autoset summary on deletion
     if(empty($summary)) $summary = $lang['deleted'];
-    //remove empty namespaces
+    // unlock early
+    unlock($id);
+    // remove empty namespaces
     io_sweepNS($id);
   }else{
     // save file (datadir is created in io_saveFile)
@@ -775,11 +841,11 @@ function saveWikiText($id,$text,$summary){
     $del = false;
   }
 
-  addLogEntry(@filemtime($file),$id,$summary);
+  addLogEntry(@filemtime($file),$id,$summary,$minor);
   // send notify mails
-  notify($id,'admin',$old,$summary);
-  notify($id,'subscribers',$old,$summary);
-  
+  notify($id,'admin',$old,$summary,$minor);
+  notify($id,'subscribers',$old,$summary,$minor);
+
   //purge cache on add by updating the purgefile
   if($conf['purgeonadd'] && (!$old || $del)){
     io_saveFile($conf['cachedir'].'/purgefile',time());
@@ -793,8 +859,7 @@ function saveWikiText($id,$text,$summary){
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function saveOldRevision($id){
-	global $conf;
-  umask($conf['umask']);
+  global $conf;
   $oldf = wikiFN($id);
   if(!@file_exists($oldf)) return '';
   $date = filemtime($oldf);
@@ -811,14 +876,15 @@ function saveOldRevision($id){
 /**
  * Sends a notify mail on page change
  *
- * @param  string $id       The changed page
- * @param  string $who      Who to notify (admin|subscribers)
- * @param  int    $rev      Old page revision
- * @param  string $summary  What changed
+ * @param  string  $id       The changed page
+ * @param  string  $who      Who to notify (admin|subscribers)
+ * @param  int     $rev      Old page revision
+ * @param  string  $summary  What changed
+ * @param  boolean $minor    Is this a minor edit?
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function notify($id,$who,$rev='',$summary=''){
+function notify($id,$who,$rev='',$summary='',$minor=false){
   global $lang;
   global $conf;
 
@@ -830,6 +896,7 @@ function notify($id,$who,$rev='',$summary=''){
     $bcc  = '';
   }elseif($who == 'subscribers'){
     if(!$conf['subscribers']) return; //subscribers enabled?
+    if($conf['useacl'] && $_SERVER['REMOTE_USER'] && $minor) return; //skip minors
     $bcc  = subscriber_addresslist($id);
     if(empty($bcc)) return;
     $to   = '';
@@ -837,7 +904,7 @@ function notify($id,$who,$rev='',$summary=''){
   }else{
     return; //just to be safe
   }
-  
+
   $text = str_replace('@DATE@',date($conf['dformat']),$text);
   $text = str_replace('@BROWSER@',$_SERVER['HTTP_USER_AGENT'],$text);
   $text = str_replace('@IPADDRESS@',$_SERVER['REMOTE_ADDR'],$text);
@@ -848,11 +915,11 @@ function notify($id,$who,$rev='',$summary=''){
   $text = str_replace('@DOKUWIKIURL@',DOKU_URL,$text);
   $text = str_replace('@SUMMARY@',$summary,$text);
   $text = str_replace('@USER@',$_SERVER['REMOTE_USER'],$text);
-  
+
   if($rev){
     $subject = $lang['mail_changed'].' '.$id;
     $text = str_replace('@OLDPAGE@',wl($id,"rev=$rev",true),$text);
-    require_once("inc/DifferenceEngine.php");
+    require_once(DOKU_INC.'inc/DifferenceEngine.php');
     $df  = new Diff(split("\n",rawWiki($id,$rev)),
                     split("\n",rawWiki($id)));
     $dformat = new UnifiedDiffFormatter();
@@ -944,7 +1011,7 @@ function filesize_h($size, $dec = 1){
   $sizes = array('B', 'KB', 'MB', 'GB');
   $count = count($sizes);
   $i = 0;
-    
+
   while ($size >= 1024 && ($i < $count - 1)) {
     $size /= 1024;
     $i++;
@@ -961,21 +1028,21 @@ function filesize_h($size, $dec = 1){
  */
 function obfuscate($email) {
   global $conf;
-  
+
   switch ($conf['mailguard']) {
     case 'visible' :
       $obfuscate = array('@' => ' [at] ', '.' => ' [dot] ', '-' => ' [dash] ');
       return strtr($email, $obfuscate);
-      
+
     case 'hex' :
       $encode = '';
       for ($x=0; $x < strlen($email); $x++) $encode .= '&#x' . bin2hex($email{$x}).';';
       return $encode;
-      
+
     case 'none' :
     default :
       return $email;
-  }            
+  }
 }
 
 /**
@@ -991,7 +1058,7 @@ function getVersion(){
   }elseif(is_dir('_darcs')){
     //darcs checkout
     $inv = file('_darcs/inventory');
-    $inv = preg_grep('#andi@splitbrain\.org\*\*\d{14}#',$inv);
+    $inv = preg_grep('#\*\*\d{14}[\]$]#',$inv);
     $cur = array_pop($inv);
     preg_match('#\*\*(\d{4})(\d{2})(\d{2})#',$cur,$matches);
     return 'Darcs '.$matches[1].'-'.$matches[2].'-'.$matches[3];
@@ -1064,7 +1131,13 @@ function check(){
   }else{
     msg('mb_string extension not available - PHP only replacements will be used',0);
   }
- 
+
+  if($conf['allowdebug']){
+    msg('Debugging support is enabled. If you don\'t need it you should set $conf[\'allowdebug\'] = 0',-1);
+  }else{
+    msg('Debugging support is disabled',1);
+  }
+
   msg('Your current permission for this page is '.$INFO['perm'],0);
 
   if(is_writable($INFO['filepath'])){
@@ -1104,9 +1177,10 @@ function is_subscribed($id,$uid){
  */
 function subscriber_addresslist($id){
   global $conf;
+  global $auth;
 
   $emails = '';
-  
+
   if (!$conf['subscribers']) return;
 
   $mlist = array();
@@ -1117,7 +1191,7 @@ function subscriber_addresslist($id){
   if(count($mlist) > 0) {
     foreach ($mlist as $who) {
       $who = rtrim($who);
-      $info = auth_getUserData($who);
+      $info = $auth->getUserData($who);
       $level = auth_aclcheck($id,$who,$info['grps']);
       if ($level >= AUTH_READ) {
         if (strcasecmp($info['mail'],$conf['notify']) != 0) {
