@@ -18,9 +18,8 @@
  */
 function ft_pageSearch($query,&$poswords){
     $q = ft_queryParser($query);
-
     // use this for higlighting later:
-    $poswords = join(' ',$q['and']);
+    $poswords = str_replace('*','',join(' ',$q['and']));
 
     // lookup all words found in the query
     $words  = array_merge($q['and'],$q['not']);
@@ -45,20 +44,23 @@ function ft_pageSearch($query,&$poswords){
     }
     if(!count($docs)) return array();
 
+    // create a list of hidden pages in the result
+    $hidden = array();
+    $hidden = array_filter(array_keys($docs),'isHiddenPage');
+    $not = array_merge($not,$hidden);
+
     // remove negative matches
     foreach($not as $n){
         unset($docs[$n]);
     }
 
     if(!count($docs)) return array();
-
     // handle phrases
     if(count($q['phrases'])){
         //build a regexp
         $q['phrases'] = array_map('utf8_strtolower',$q['phrases']);
         $q['phrases'] = array_map('preg_quote',$q['phrases']);
         $regex = '('.join('|',$q['phrases']).')';
-
         // check the source of all documents for the exact phrases
         foreach(array_keys($docs) as $id){
             $text  = utf8_strtolower(rawWiki($id));
@@ -98,14 +100,14 @@ function ft_backlinks($id){
     // quick lookup of the pagename
     $page    = noNS($id);
     $sw      = array(); // we don't use stopwords here
-    $matches = idx_lookup(idx_tokenizer($page,$sw));  //pagename may contain specials (_ or .)
-    $docs = ft_resultCombine(array_values($matches));
-
+    $matches = idx_lookup(idx_tokenizer($page,$sw));  // pagename may contain specials (_ or .)
+    $docs    = array_keys(ft_resultCombine(array_values($matches)));
+    $docs    = array_filter($docs,'isVisiblePage'); // discard hidden pages
     if(!count($docs)) return $result;
     require_once(DOKU_INC.'inc/parserutils.php');
 
     // check instructions for matching links
-    foreach(array_keys($docs) as $match){
+    foreach($docs as $match){
         $instructions = p_cached_instructions(wikiFN($match),true);
         if(is_null($instructions)) continue;
 
@@ -157,7 +159,7 @@ function ft_pageLookup($id,$pageonly=true){
             if(!preg_match('/'.$id.'/',noNS($pages[$i]))){
                 unset($pages[$i]);
                 continue;
-            } 
+            }
         }
         if(!@file_exists(wikiFN($pages[$i]))){
             unset($pages[$i]);
@@ -165,6 +167,7 @@ function ft_pageLookup($id,$pageonly=true){
         }
     }
 
+    $pages = array_filter($pages,'isVisiblePage'); // discard hidden pages
     if(!count($pages)) return array();
 
     // check ACL permissions
@@ -216,6 +219,10 @@ function ft_snippet($id,$poswords){
  */
 function ft_resultCombine($args){
     $array_count = count($args);
+    if($array_count == 1){
+        return $args[0];
+    }
+
     $result = array();
     foreach ($args[0] as $key1 => $value1) {
         for ($i = 1; $i !== $array_count; $i++) {
@@ -234,6 +241,7 @@ function ft_resultCombine($args){
  * Builds an array of search words from a query
  *
  * @todo support OR and parenthesises?
+ * @todo add namespace handling
  */
 function ft_queryParser($query){
     global $conf;
@@ -249,10 +257,10 @@ function ft_queryParser($query){
     $q['phrases'] = array();
     $q['and']     = array();
     $q['not']     = array();
-    
+
     // handle phrase searches
     while(preg_match('/"(.*?)"/',$query,$match)){
-        $q['phrases'][] = $match[0];
+        $q['phrases'][] = $match[1];
         $q['and'] = array_merge(idx_tokenizer($match[0],$stopwords));
         $query = preg_replace('/"(.*?)"/','',$query,1);
     }
@@ -260,10 +268,15 @@ function ft_queryParser($query){
     $words = explode(' ',$query);
     foreach($words as $w){
         if($w{0} == '-'){
-            $token = idx_tokenizer($w,$stopwords);
+            $token = idx_tokenizer($w,$stopwords,true);
             if(count($token)) $q['not'] = array_merge($q['not'],$token);
         }else{
-            $token = idx_tokenizer($w,$stopwords);
+            // asian "words" need to be searched as phrases
+            if(@preg_match_all('/('.IDX_ASIAN.'+)/u',$w,$matches)){
+                $q['phrases'] = array_merge($q['phrases'],$matches[1]);
+
+            }
+            $token = idx_tokenizer($w,$stopwords,true);
             if(count($token)) $q['and'] = array_merge($q['and'],$token);
         }
     }
