@@ -28,7 +28,7 @@
  * @author    Nigel McNie <nigel@geshi.org>
  * @copyright Copyright &copy; 2004, 2005, Nigel McNie
  * @license   http://gnu.org/copyleft/gpl.html GNU GPL
- * @version   $Id: geshi.php,v 1.15 2005/09/22 01:41:46 oracleshinoda Exp $
+ * @version   $Id: geshi.php,v 1.30 2006/02/25 00:46:33 oracleshinoda Exp $
  *
  */
 
@@ -40,10 +40,7 @@
 //
 
 /** The version of this GeSHi file */
-define('GESHI_VERSION', '1.0.7.3');
-
-/** For the future (though this may never be realised) */
-define('GESHI_OUTPUT_HTML', 0);
+define('GESHI_VERSION', '1.0.7.7');
 
 /** Set the correct directory separator */
 define('GESHI_DIR_SEPARATOR', ('WIN' != substr(PHP_OS, 0, 3)) ? '/' : '\\');
@@ -131,7 +128,9 @@ define('GESHI_AFTER', 4);
 define('GESHI_COMMENTS', 0);
 
 // Error detection - use these to analyse faults
-/** No sourcecode to highlight was specified */
+/** No sourcecode to highlight was specified
+ * @deprecated
+ */
 define('GESHI_ERROR_NO_INPUT', 1);
 /** The language specified does not exist */
 define('GESHI_ERROR_NO_SUCH_LANG', 2);
@@ -196,7 +195,7 @@ class GeSHi
      * @var array
      */
     var $error_messages = array(
-        GESHI_ERROR_NO_INPUT => 'No source code inputted',
+        //GESHI_ERROR_NO_INPUT => 'No source code inputted',
         GESHI_ERROR_NO_SUCH_LANG => 'GeSHi could not find the language {LANGUAGE} (using path {PATH})',
         GESHI_ERROR_FILE_NOT_READABLE => 'The file specified for load_from_file was not readable',
         GESHI_ERROR_INVALID_HEADER_TYPE => 'The header type specified is invalid',
@@ -224,6 +223,7 @@ class GeSHi
      *   a &lt;pre&gt; HTML element.</li>
      *   <li><b>GESHI_HEADER_DIV</b>: Source is outputted in
      *   a &lt;div&gt; HTML element.</li>
+     *   <li><b>GESHI_HEADER_NONE</b>: No header is outputted.</li>
      * </ul>
      * 
      * @var int
@@ -286,6 +286,7 @@ class GeSHi
     /**
      * Whether important blocks should be recognised or not
      * @var boolean
+     * @deprecated
      * @todo REMOVE THIS FUNCTIONALITY!
      */
 	var $enable_important_blocks = false;
@@ -293,6 +294,7 @@ class GeSHi
     /**
      * Styles for important parts of the code
      * @var string
+     * @deprecated
      * @todo As above - rethink the whole idea of important blocks as it is buggy and
      * will be hard to implement in 1.2
      */
@@ -389,12 +391,6 @@ class GeSHi
      */
 	var $encoding = 'ISO-8859-1';
 
-	/**
-     * Unused (planned for future)
-     * @var int
-	 */
-	var $output_format = GESHI_OUTPUT_HTML;
-
     /**#@-*/
 
 	/**
@@ -413,7 +409,7 @@ class GeSHi
 	 */
 	function GeSHi ($source, $language, $path = '')
 	{
-		$this->set_source($source);
+        $this->set_source($source);
         $this->set_language_path($path);
         $this->set_language($language);
 	}
@@ -464,9 +460,6 @@ class GeSHi
 	 */
 	function set_source ($source)
 	{
-        if ('' == trim($source)) {
-            $this->error = GESHI_ERROR_NO_INPUT;
-        }
 		$this->source = $source;
 	}
 
@@ -508,7 +501,8 @@ class GeSHi
 	function set_language_path ($path)
 	{
         if ($path) {
-		  $this->language_path = ('/' == substr($path, strlen($path) - 1, 1)) ? $path : $path . '/';
+			$this->language_path = ('/' == substr($path, strlen($path) - 1, 1)) ? $path : $path . '/';
+			$this->set_language($this->language);	    // otherwise set_language_path has no effect
         }
 	}
 
@@ -1305,6 +1299,7 @@ class GeSHi
 	 * Sets whether context-important blocks are highlighted
      * 
      * @todo REMOVE THIS SHIZ FROM GESHI!
+     * @deprecated
 	 */
 	function enable_important_blocks ( $flag )
 	{
@@ -1403,15 +1398,10 @@ class GeSHi
 
 		// Firstly, if there is an error, we won't highlight
 		if ($this->error) {
-			$result = $this->header();
-			if ($this->header_type != GESHI_HEADER_PRE) {
-				$result .= $this->indent(@htmlspecialchars($this->source, ENT_COMPAT, $this->encoding));
-			} else {
-				$result .= @htmlspecialchars($this->source, ENT_COMPAT, $this->encoding);
-			}
-			// Stop Timing
-			$this->set_time($start_time, microtime());
-			return $result . $this->footer();
+            $result = @htmlspecialchars($this->source, ENT_COMPAT, $this->encoding);
+			// Timing is irrelevant
+			$this->set_time($start_time, $start_time);
+			return $this->finalise($result);
 		}
 
 		// Add spaces for regular expression matching and line numbers
@@ -1430,6 +1420,7 @@ class GeSHi
 		$HIGHLIGHTING_ON  = ( !$this->strict_mode ) ? true : '';
 		// Whether to highlight inside a block of code
 		$HIGHLIGHT_INSIDE_STRICT = false;
+		$HARDQUOTE_OPEN = false;
 		$stuff_to_parse   = '';
 		$result           = '';
 
@@ -1538,6 +1529,7 @@ class GeSHi
 					for ($i = 0; $i < $length; $i++) {
 						// Get the next char
 						$char = substr($part, $i, 1);
+				        $hq = isset($this->language_data['HARDQUOTE']) ? $this->language_data['HARDQUOTE'][0] : false;
 						// Is this char the newline and line numbers being used?
 						if (($this->line_numbers != GESHI_NO_LINE_NUMBERS
                             || count($this->highlight_extra_lines) > 0)
@@ -1561,10 +1553,27 @@ class GeSHi
                                 ($this->lexic_permissions['STRINGS'] && !$ESCAPE_CHAR_OPEN)) {
 								$char .= '</span>';
 							}
+						    $escape_me = false;
+    						if ($HARDQUOTE_OPEN)
+	    					{
+	    						if ($ESCAPE_CHAR_OPEN)
+								$escape_me = true;
+		    					else {
+			    					foreach ($this->language_data['HARDESCAPE'] as $hardesc)
+				    				if (substr($part, $i, strlen($hardesc)) == $hardesc)
+					    			{
+						    			$escape_me = true;
+							    		break;
+							    	}
+							    }
+						    }
 							if (!$ESCAPE_CHAR_OPEN) {
 								$STRING_OPEN = '';
 								$CLOSE_STRING = true;
 							}
+						    if (!$escape_me) {
+						    	$HARDQUOTE_OPEN = false;
+						    }
 							$ESCAPE_CHAR_OPEN = false;
 						} elseif (in_array($char, $this->language_data['QUOTEMARKS']) &&
                             ($STRING_OPEN == '') && $this->lexic_permissions['STRINGS']) {
@@ -1579,17 +1588,51 @@ class GeSHi
 
 							$result .= $this->parse_non_string_part( $stuff_to_parse );
 							$stuff_to_parse = '';
-						} elseif (($char == $this->language_data['ESCAPE_CHAR']) && ($STRING_OPEN != '')) {
+    				    } elseif (
+    					$hq &&
+    					substr($part, $i, strlen($hq)) == $hq &&
+    					($STRING_OPEN == '') && $this->lexic_permissions['STRINGS']
+    				    )
+    				    {
+    					// The start of a hard quoted string
+    					$STRING_OPEN = $this->language_data['HARDQUOTE'][1];
+    					if (!$this->use_classes) {
+    					    $attributes = ' style="' . $this->language_data['STYLES']['STRINGS'][0] . '"';
+    					} else {
+    					    $attributes = ' class="st0"';
+    					}
+    					$char = "<span$attributes>" . $hq;
+    					$i += strlen($hq) - 1;
+    					$HARDQUOTE_OPEN = true;
+    					$result .= $this->parse_non_string_part( $stuff_to_parse );
+    					$stuff_to_parse = '';
+    				    } elseif ($char == $this->language_data['ESCAPE_CHAR'] && $STRING_OPEN != '')
+    				    {
                             // An escape character
 							if (!$ESCAPE_CHAR_OPEN) {
+    							$ESCAPE_CHAR_OPEN = !$HARDQUOTE_OPEN;  // true unless $HARDQUOTE_OPEN
+    							if ($HARDQUOTE_OPEN)
+    								foreach ($this->language_data['HARDESCAPE'] as $hard)
+    								{
+    									if (substr($part, $i, strlen($hard)) == $hard)
+    									{
 								$ESCAPE_CHAR_OPEN = true;
-								if ($this->lexic_permissions['ESCAPE_CHAR']) {
+    										break;
+    									}
+    								}
+    							if ($ESCAPE_CHAR_OPEN && $this->lexic_permissions['ESCAPE_CHAR']) {
 									if (!$this->use_classes) {
 										$attributes = ' style="' . $this->language_data['STYLES']['ESCAPE_CHAR'][0] . '"';
 									} else {
 										$attributes = ' class="es0"';
 									}
 									$char = "<span$attributes>" . $char;
+                                    if (substr($code, $i + 1, 1) == "\n") {
+                                        // escaping a newline, what's the point in putting the span around
+                                        // the newline? It only causes hassles when inserting line numbers
+                                        $char .= '</span>';
+                                        $ESCAPE_CHAR_OPEN = false;
+                                    }
 								}
 							} else {
 								$ESCAPE_CHAR_OPEN = false;
@@ -1687,14 +1730,19 @@ class GeSHi
 											$test_str = @htmlspecialchars($test_str, ENT_COMPAT, $this->encoding);
 										}
 										$close_pos = strpos($part, "\n", $i);
+                                        $oops = false;
 										if ($close_pos === false) {
 											$close_pos = strlen($part);
+                                            $oops = true;
 										}
 										$test_str .= @htmlspecialchars(substr($part, $i + $com_len, $close_pos - $i - $com_len), ENT_COMPAT, $this->encoding);
 										if ($this->lexic_permissions['COMMENTS'][$comment_key]) {
 											$test_str .= "</span>";
 										}
-										$test_str .= "\n";
+                                        // Take into account that the comment might be the last in the source
+                                        if (!$oops) { 
+										  $test_str .= "\n";
+                                        }
 										$i = $close_pos;
 										// parse the rest
 										$result .= $this->parse_non_string_part($stuff_to_parse);
@@ -1735,10 +1783,10 @@ class GeSHi
 					$result .= @htmlspecialchars($part, ENT_COMPAT, $this->encoding);
 				}
 				// Close the <span> that surrounds the block
-                // Removed since the only time this is used is for php and it doesn't need a </span>
-				/*if ($this->strict_mode && $this->lexic_permissions['SCRIPT']) {
+				if ($this->strict_mode && $this->language_data['STYLES']['SCRIPT'][$script_key] != '' &&
+                    $this->lexic_permissions['SCRIPT']) {
 					$result .= '</span>';
-				}*/
+				}
 			} else {
                 // Else not a block to highlight
 				$result .= @htmlspecialchars($part, ENT_COMPAT, $this->encoding);
@@ -1892,25 +1940,35 @@ class GeSHi
 	 */
 	function add_url_to_keyword ($keyword, $group, $start_or_end)
 	{
-		if (isset($this->language_data['URLS'][$group]) &&
+        if (isset($this->language_data['URLS'][$group]) &&
             $this->language_data['URLS'][$group] != '' &&
             substr($keyword, 0, 5) != '&lt;/') {
 			// There is a base group for this keyword
 			if ($start_or_end == 'BEGIN') {
 				// HTML workaround... not good form (tm) but should work for 1.0.X
-				$keyword = ( substr($keyword, 0, 4) == '&lt;' ) ? substr($keyword, 4) : $keyword;
-				$keyword = ( substr($keyword, -4) == '&gt;' ) ? substr($keyword, 0, strlen($keyword) - 4) : $keyword;
 				if ($keyword != '') {
-					$keyword = ( $this->language_data['CASE_SENSITIVE'][$group] ) ? $keyword : strtolower($keyword);
+                    // Old system: strtolower
+					//$keyword = ( $this->language_data['CASE_SENSITIVE'][$group] ) ? $keyword : strtolower($keyword);
+                    // New system: get keyword from language file to get correct case
+                    foreach ($this->language_data['KEYWORDS'][$group] as $word) {
+                        if (strtolower($word) == strtolower($keyword)) {
+                            break;
+                        }
+                    }
+                    $word = ( substr($word, 0, 4) == '&lt;' ) ? substr($word, 4) : $word;
+                    $word = ( substr($word, -4) == '&gt;' ) ? substr($word, 0, strlen($word) - 4) : $word;
+                    if (!$word) return '';
+                    
 					return '<|UR1|"' .
                         str_replace(
                             array('{FNAME}', '.'),
-                            array(@htmlspecialchars($keyword, ENT_COMPAT, $this->encoding), '<DOT>'),
+                            array(@htmlspecialchars($word, ENT_COMPAT, $this->encoding), '<DOT>'),
                             $this->language_data['URLS'][$group]
                         ) . '">';
 				}
 				return '';
-			} else {
+            // HTML fix. Again, dirty hackage...
+			} elseif (!($this->language == 'html4strict' && '&gt;' == $keyword)) {
 				return '</a>';
 			}
 		}
@@ -1957,10 +2015,15 @@ class GeSHi
 		// almost exactly the same thing, except the second one prevents a number
 		// being highlighted twice (eg <span...><span...>5</span></span>)
 		// Put /NUM!/ in for the styles, which gets replaced at the end.
+        //
+        // NEW ONE: Brice Bernard
+        // $stuff_to_parse = preg_replace('/([^(\\w|#|\\\|"|\')])(\\d+)/', '\\1<|/NUM!/>\\2|>', $stuff_to_parse);
+        //$stuff_to_parse = preg_replace('/([-+]?\\b(?:[0-9]*\\.)?[0-9]+\\b)/', '<|/NUM!/>\\1|>', $stuff_to_parse);
 		//
 		if ($this->lexic_permissions['NUMBERS'] && preg_match('#[0-9]#', $stuff_to_parse )) {
-			$stuff_to_parse = preg_replace('#([^a-zA-Z0-9\#])([0-9]+)([^a-zA-Z0-9])#', "\\1<|/NUM!/>\\2|>\\3", $stuff_to_parse);
-			$stuff_to_parse = preg_replace('#([^a-zA-Z0-9\#>])([0-9]+)([^a-zA-Z0-9])#', "\\1<|/NUM!/>\\2|>\\3", $stuff_to_parse);
+			//$stuff_to_parse = preg_replace('#([^a-zA-Z0-9_\#])([0-9]+)([^a-zA-Z0-9])#', "\\1<|/NUM!/>\\2|>\\3", $stuff_to_parse);
+			//$stuff_to_parse = preg_replace('#([^a-zA-Z0-9_\#>])([0-9]+)([^a-zA-Z0-9])#', "\\1<|/NUM!/>\\2|>\\3", $stuff_to_parse);
+            $stuff_to_parse = preg_replace('/([-+]?\\b(?:[0-9]*\\.)?[0-9]+\\b)/', '<|/NUM!/>\\1|>', $stuff_to_parse);
 		}
 
 		// Highlight keywords
@@ -1985,15 +2048,15 @@ class GeSHi
 							$keyword = quotemeta($keyword);
 							if ($this->language_data['CASE_SENSITIVE'][$k]) {
 								$stuff_to_parse = preg_replace(
-                                    "#([^a-zA-Z0-9\$_\|\#;>])($keyword)([^a-zA-Z0-9_<\|%\-&])#e",
-                                    "'\\1' . $func2('\\2', '$k', 'BEGIN') . '<|$styles>' . $func('\\2') . '|>' . $func2('\\2', '$k', 'END') . '\\3'",
+                                    "#([^a-zA-Z0-9\$_\|\#;>])($keyword)(?=[^a-zA-Z0-9_<\|%\-&])#e",
+                                    "'\\1' . $func2('\\2', '$k', 'BEGIN') . '<|$styles>' . $func('\\2') . '|>' . $func2('\\2', '$k', 'END')",
                                     $stuff_to_parse
                                 );
 							} else {
 								// Change the case of the word.
 								$stuff_to_parse = preg_replace(
-                                    "#([^a-zA-Z0-9\$_\|\#;>])($keyword)([^a-zA-Z0-9_<\|%\-&])#ie",
-                                    "'\\1' . $func2('\\2', '$k', 'BEGIN') . '<|$styles>' . $func('\\2') . '|>' . $func2('\\2', '$k', 'END') . '\\3'",
+                                    "#([^a-zA-Z0-9\$_\|\#;>])($keyword)(?=[^a-zA-Z0-9_<\|%\-&])#ie",
+                                    "'\\1' . $func2('\\2', '$k', 'BEGIN') . '<|$styles>' . $func('\\2') . '|>' . $func2('\\2', '$k', 'END')",
                                     $stuff_to_parse
                                 );
 							}
@@ -2305,7 +2368,10 @@ class GeSHi
 		$header = $this->format_header_content();
 
         if (GESHI_HEADER_NONE == $this->header_type) {
-            return "$header<ol$ol_attributes>";
+            if ($this->line_numbers != GESHI_NO_LINE_NUMBERS) {
+                return "$header<ol$ol_attributes>";
+            }
+            return $header;
         }
         
 		// Work out what to return and do it
@@ -2397,7 +2463,7 @@ class GeSHi
 			if ($this->use_classes) {
 				$attr = ' class="foot"';
 			} else {
-				$attr = " style=\"{$this->footer_content_style}\">";
+				$attr = " style=\"{$this->footer_content_style}\"";
 			}
 			return "<div$attr>$footer</div>";
 		}
@@ -2615,11 +2681,11 @@ if (!function_exists('geshi_highlight')) {
 	function geshi_highlight ($string, $language, $path, $return = false)
 	{
 		$geshi = new GeSHi($string, $language, $path);
-		$geshi->set_header_type(GESHI_HEADER_DIV);
+		$geshi->set_header_type(GESHI_HEADER_NONE);
 		if ($return) {
-			return str_replace('<div>', '<code>', str_replace('</div>', '</code>', $geshi->parse_code()));
+			return '<code>' . $geshi->parse_code() . '</code>';
 		}
-		echo str_replace('<div>', '<code>', str_replace('</div>', '</code>', $geshi->parse_code()));
+		echo '<code>' . $geshi->parse_code() . '</code>';
 		if ($geshi->error()) {
 			return false;
 		}
