@@ -4,15 +4,17 @@
  * --------
  * Author: Roberto Rossi (rsoftware@altervista.org)
  * Copyright: (c) 2004 Roberto Rossi (http://rsoftware.altervista.org), Nigel McNie (http://qbnz.com/highlighter
- * Release Version: 1.0.7.3
- * CVS Revision Version: $Revision: 1.4 $
+ * Release Version: 1.0.7.7
+ * CVS Revision Version: $Revision: 1.9 $
  * Date Started: 2004/08/30
- * Last Modified: $Date: 2005/09/22 01:35:22 $
+ * Last Modified: $Date: 2006/02/25 00:46:33 $
  *
  * Generic Lisp language file for GeSHi.
  *
  * CHANGES
  * -------
+ * 2005/12/9  (1.0.2)
+ *  -  Added support for :keywords and ::access (Denis Mashkevich)
  * 2004/11/27 (1.0.1)
  *  -  Added support for multiple object splitters
  * 2004/08/30 (1.0.0)
@@ -104,7 +106,8 @@ $language_data = array (
 			0 => 'color: #cc66cc;'
 			),
 		'METHODS' => array(
-			0 => 'color: #202020;'
+			0 => 'color: #555;',
+            1 => 'color: #555;'
 			),
 		'SYMBOLS' => array(
 			0 => 'color: #66cc66;'
@@ -116,8 +119,9 @@ $language_data = array (
 		),
 	'URLS' => array(
 		),
-	'OOLANG' => false,
+	'OOLANG' => true,
 	'OBJECT_SPLITTERS' => array(
+            '::', ':'
 		),
 	'REGEXPS' => array(
 		),
