@@ -4,15 +4,17 @@
  * -------
  * Author: Nigel McNie (oracle.shinoda@gmail.com)
  * Copyright: (c) 2004 Nigel McNie (http://qbnz.com/highlighter/)
- * Release Version: 1.0.7.3
- * CVS Revision Version: $Revision: 1.6 $
+ * Release Version: 1.0.7.7
+ * CVS Revision Version: $Revision: 1.12 $
  * Date Started: 2004/09/01
- * Last Modified: $Date: 2005/09/22 01:41:46 $
+ * Last Modified: $Date: 2006/02/25 00:46:33 $
  *
  * XML language file for GeSHi. Based on the idea/file by Christian Weiske
  *
  * CHANGES
  * -------
+ * 2005/12/28 (1.0.2)
+ *   -  Removed escape character for strings
  * 2004/11/27 (1.0.1)
  *   -  Added support for multiple object splitters
  * 2004/10/27 (1.0.0)
@@ -48,7 +50,7 @@ $language_data = array (
 	'COMMENT_MULTI' => array('<!--' => '-->'),
 	'CASE_KEYWORDS' => GESHI_CAPS_NO_CHANGE,
 	'QUOTEMARKS' => array("'", '"'),
-	'ESCAPE_CHAR' => '\\',
+	'ESCAPE_CHAR' => '',
 	'KEYWORDS' => array(
 		),
 	'SYMBOLS' => array(
