@@ -16,10 +16,10 @@
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function html_wikilink($id,$name=NULL,$search=''){
-  require_once(DOKU_INC.'inc/parser/xhtml.php');
   static $xhtml_renderer = NULL;
   if(is_null($xhtml_renderer)){
-    $xhtml_renderer = new Doku_Renderer_xhtml(); 
+    require_once(DOKU_INC.'inc/parser/xhtml.php');
+    $xhtml_renderer = new Doku_Renderer_xhtml();
   }
 
   return $xhtml_renderer->internallink($id,$name,$search,true);
@@ -47,37 +47,45 @@ function html_login(){
   global $lang;
   global $conf;
   global $ID;
+  global $auth;
 
   print p_locale_xhtml('login');
   ?>
-    <div align="center">
+    <div class="centeralign">
     <form action="<?php echo script()?>" accept-charset="<?php echo $lang['encoding']?>" method="post">
       <fieldset>
         <legend><?php echo $lang['btn_login']?></legend>
         <input type="hidden" name="id" value="<?php echo $ID?>" />
         <input type="hidden" name="do" value="login" />
-        <label>
+        <label class="block">
           <span><?php echo $lang['user']?></span>
           <input type="text" name="u" value="<?php echo formText($_REQUEST['u'])?>" class="edit" />
         </label><br />
-        <label>
+        <label class="block">
           <span><?php echo $lang['pass']?></span>
           <input type="password" name="p" class="edit" />
         </label><br />
         <input type="submit" value="<?php echo $lang['btn_login']?>" class="button" />
-        <label for="remember" class="simple">
-          <input type="checkbox" name="r" id="remember" value="1" />
+        <label for="remember__me" class="simple">
+          <input type="checkbox" name="r" id="remember__me" value="1" />
           <span><?php echo $lang['remember']?></span>
         </label>
       </fieldset>
     </form>
   <?php
-    if($conf['openregister']){
+    if($auth->canDo('addUser') && $conf['openregister']){
       print '<p>';
       print $lang['reghere'];
       print ': <a href="'.wl($ID,'do=register').'" class="wikilink1">'.$lang['register'].'</a>';
       print '</p>';
     }
+
+    if ($auth->canDo('modPass') && $conf['resendpasswd']) {
+      print '<p>';
+      print $lang['pwdforget'];
+      print ': <a href="'.wl($ID,'do=resendpwd').'" class="wikilink1">'.$lang['btn_resendpwd'].'</a>';
+      print '</p>';
+    }
   ?>
     </div>
   <?php
@@ -165,7 +173,7 @@ function html_topbtn(){
   global $lang;
 
   $ret  = '';
-  $ret  = '<a href="#top"><input type="button" class="button" value="'.$lang['btn_top'].'" onclick="window.scrollTo(0, 0)" /></a>';
+  $ret  = '<a href="#dokuwiki__top"><input type="button" class="button" value="'.$lang['btn_top'].'" onclick="window.scrollTo(0, 0)" /></a>';
 
   return $ret;
 }
@@ -178,22 +186,22 @@ function html_topbtn(){
 function html_backtomedia_button($params,$akey=''){
   global $conf;
   global $lang;
-  
-  $ret = '<form class="button" method="get" action="'.DOKU_BASE.'lib/exe/media.php">';
-  
+
+  $ret = '<form class="button" method="get" action="'.DOKU_BASE.'lib/exe/media.php"><div class="no">';
+
   reset($params);
   while (list($key, $val) = each($params)) {
     $ret .= '<input type="hidden" name="'.$key.'" ';
     $ret .= 'value="'.htmlspecialchars($val).'" />';
   }
-  
+
   $ret .= '<input type="submit" value="'.htmlspecialchars($lang['btn_backtomedia']).'" class="button" ';
   if($akey){
     $ret .= 'title="ALT+'.strtoupper($akey).'" ';
     $ret .= 'accesskey="'.$akey.'" ';
   }
   $ret .= '/>';
-  $ret .= '</form>';
+  $ret .= '</div></form>';
 
   return $ret;
 }
@@ -206,15 +214,15 @@ function html_backtomedia_button($params,$akey=''){
 function html_btn($name,$id,$akey,$params,$method='get'){
   global $conf;
   global $lang;
-  
+
   $label = $lang['btn_'.$name];
-  
+
   $ret = '';
 
   //filter id (without urlencoding)
   $id = idfilter($id,false);
 
-  //make nice URLs even for buttons 
+  //make nice URLs even for buttons
   if($conf['userewrite'] == 2){
     $script = DOKU_BASE.DOKU_SCRIPT.'/'.$id;
   }elseif($conf['userewrite']){
@@ -223,22 +231,24 @@ function html_btn($name,$id,$akey,$params,$method='get'){
     $script = DOKU_BASE.DOKU_SCRIPT;
     $params['id'] = $id;
   }
- 
-  $ret .= '<form class="button" method="'.$method.'" action="'.$script.'" onsubmit="return svchk()">';
-  
-  reset($params);
-  while (list($key, $val) = each($params)) {
-    $ret .= '<input type="hidden" name="'.$key.'" ';
-    $ret .= 'value="'.htmlspecialchars($val).'" />';
+
+  $ret .= '<form class="button" method="'.$method.'" action="'.$script.'"><div class="no">';
+
+  if(is_array($params)){
+    reset($params);
+    while (list($key, $val) = each($params)) {
+      $ret .= '<input type="hidden" name="'.$key.'" ';
+      $ret .= 'value="'.htmlspecialchars($val).'" />';
+    }
   }
-  
+
   $ret .= '<input type="submit" value="'.htmlspecialchars($label).'" class="button" ';
   if($akey){
     $ret .= 'title="ALT+'.strtoupper($akey).'" ';
     $ret .= 'accesskey="'.$akey.'" ';
   }
   $ret .= '/>';
-  $ret .= '</form>';
+  $ret .= '</div></form>';
 
   return $ret;
 }
@@ -258,12 +268,14 @@ function html_show($txt=''){
   }else{
     $secedit = true;
   }
-  
+
   if ($txt){
     //PreviewHeader
+    print '<br id="scroll__here" />';
     print p_locale_xhtml('preview');
     print '<div class="preview">';
     print html_secedit(p_render('xhtml',p_get_instructions($txt),$info),$secedit);
+    print '<div class="clearer"></div>';
     print '</div>';
 
   }else{
@@ -278,16 +290,31 @@ function html_show($txt=''){
  * Highlights searchqueries in HTML code
  *
  * @author Andreas Gohr <andi@splitbrain.org>
+ * @author Harry Fuecks <hfuecks@gmail.com>
  */
 function html_hilight($html,$query){
-  $queries = preg_split ("/\s/",$query,-1,PREG_SPLIT_NO_EMPTY);
+  //split at common delimiters
+  $queries = preg_split ('/[\s\'"\\\\`()\]\[?:!\.{};,#+*<>\\/]+/',$query,-1,PREG_SPLIT_NO_EMPTY);
   foreach ($queries as $q){
-    $q = preg_quote($q,'/');
-    $html = preg_replace("/((<[^>]*)|$q)/ie", '"\2"=="\1"? unslash("\1"):"<span class=\"search_hit\">".unslash("\1")."</span>"', $html);
+     $q = preg_quote($q,'/');
+     $html = preg_replace_callback("/((<[^>]*)|$q)/i",'html_hilight_callback',$html);
   }
   return $html;
 }
 
+/**
+ * Callback used by html_hilight()
+ *
+ * @author Harry Fuecks <hfuecks@gmail.com>
+ */
+function html_hilight_callback($m) {
+  $hlight = unslash($m[0]);
+  if ( !isset($m[2])) {
+    $hlight = '<span class="search_hit">'.$hlight.'</span>';
+  }
+  return $hlight;
+}
+
 /**
  * Run a search and display the result
  *
@@ -305,11 +332,12 @@ function html_search(){
   flush();
 
   //show progressbar
-  print '<div align="center">';
-  print '<script language="javascript" type="text/javascript" charset="utf-8">';
-  print 'showLoadBar();';
-  print '</script>';
+  print '<div class="centeralign" id="dw__loading">';
   print '<br /></div>';
+  print '<script type="text/javascript" charset="utf-8">';
+  print 'showLoadBar("dw__loading");';
+  print '</script>';
+  flush();
 
   //do quick pagesearch
   $data = array();
@@ -317,12 +345,14 @@ function html_search(){
   if(count($data)){
     sort($data);
     print '<div class="search_quickresult">';
-    print '<b>'.$lang[quickhits].':</b><br />';
+    print '<h3>'.$lang[quickhits].':</h3>';
+    print '<ul class="search_quickhits">';
     foreach($data as $id){
-      print '<div class="search_quickhits">';
+      print '<li> ';
       print html_wikilink(':'.$id,$conf['useheading']?NULL:$id);
-      print '</div> ';
+      print '</li> ';
     }
+    print '</ul> ';
     //clear float (see http://www.complexspiral.com/publications/containing-floats/)
     print '<div class="clearer">&nbsp;</div>';
     print '</div>';
@@ -349,9 +379,10 @@ function html_search(){
   }
 
   //hide progressbar
-  print '<script language="javascript" type="text/javascript" charset="utf-8">';
-  print 'hideLoadBar();';
+  print '<script type="text/javascript" charset="utf-8">';
+  print 'hideLoadBar("dw__loading");';
   print '</script>';
+  flush();
 }
 
 /**
@@ -364,15 +395,15 @@ function html_locked(){
   global $conf;
   global $lang;
   global $INFO;
-  
+
   $locktime = filemtime(wikiFN($ID).'.lock');
   $expire = @date($conf['dformat'], $locktime + $conf['locktime'] );
   $min    = round(($conf['locktime'] - (time() - $locktime) )/60);
 
   print p_locale_xhtml('locked');
   print '<ul>';
-  print '<li><b>'.$lang['lockedby'].':</b> '.$INFO['locked'].'</li>';
-  print '<li><b>'.$lang['lockexpire'].':</b> '.$expire.' ('.$min.' min)</li>';
+  print '<li><div class="li"><strong>'.$lang['lockedby'].':</strong> '.$INFO['locked'].'</li>';
+  print '<li><div class="li"><strong>'.$lang['lockexpire'].':</strong> '.$expire.' ('.$min.' min)</div></li>';
   print '</ul>';
 }
 
@@ -386,17 +417,18 @@ function html_revisions(){
   global $INFO;
   global $conf;
   global $lang;
-  $revisions = getRevisions($ID); 
+  $revisions = getRevisions($ID);
   $date = @date($conf['dformat'],$INFO['lastmod']);
-  
+
   print p_locale_xhtml('revisions');
   print '<ul>';
   if($INFO['exists']){
-    print '<li>';
+    print ($INFO['minor']) ? '<li class="minor">' : '<li>';
+    print '<div class="li">';
 
     print $date;
 
-    print ' <img src="'.DOKU_BASE.'lib/images/blank.gif" border="0" width="15" height="11" alt="" /> ';
+    print ' <img src="'.DOKU_BASE.'lib/images/blank.gif" width="15" height="11" alt="" /> ';
 
     print '<a class="wikilink1" href="'.wl($ID).'">'.$ID.'</a> ';
 
@@ -406,6 +438,7 @@ function html_revisions(){
     print '</span> ';
 
     print '('.$lang['current'].')';
+    print '</div>';
     print '</li>';
   }
 
@@ -413,14 +446,13 @@ function html_revisions(){
     $date = date($conf['dformat'],$rev);
     $info = getRevisionInfo($ID,$rev);
 
-    print '<li>';
-
+    print ($info['minor']) ? '<li class="minor">' : '<li>';
+    print '<div class="li">';
     print $date;
 
     print ' <a href="'.wl($ID,"rev=$rev,do=diff").'">';
     $p = array();
     $p['src']    = DOKU_BASE.'lib/images/diff.png';
-    $p['border'] = 0;
     $p['width']  = 15;
     $p['height'] = 11;
     $p['title']  = $lang['diff'];
@@ -440,6 +472,7 @@ function html_revisions(){
     }
     print '</span>';
 
+    print '</div>';
     print '</li>';
   }
   print '</ul>';
@@ -459,26 +492,26 @@ function html_recent($first=0){
    * decide if this is the last page or is there another one.
    * This is the cheapest solution to get this information.
    */
-  $recents = getRecents($first,$conf['recent'] + 1,true,getNS($ID));
+  $recents = getRecents($first,$conf['recent'] + 1,getNS($ID));
   if(count($recents) == 0 && $first != 0){
     $first=0;
-    $recents = getRecents(0,$conf['recent'] + 1,true,getNS($ID));
+    $recents = getRecents(0,$conf['recent'] + 1,getNS($ID));
   }
-  $cnt = count($recents) <= $conf['recent'] ? count($recents) : $conf['recent']; 
+  $cnt = count($recents) <= $conf['recent'] ? count($recents) : $conf['recent'];
 
   print p_locale_xhtml('recent');
   print '<ul>';
-  
+
   foreach($recents as $recent){
     $date = date($conf['dformat'],$recent['date']);
-    print '<li>';
+    print ($recent['minor']) ? '<li class="minor">' : '<li>';
+    print '<div class="li">';
 
     print $date.' ';
 
     print '<a href="'.wl($recent['id'],"do=diff").'">';
     $p = array();
     $p['src']    = DOKU_BASE.'lib/images/diff.png';
-    $p['border'] = 0;
     $p['width']  = 15;
     $p['height'] = 11;
     $p['title']  = $lang['diff'];
@@ -490,7 +523,6 @@ function html_recent($first=0){
     print '<a href="'.wl($recent['id'],"do=revisions").'">';
     $p = array();
     $p['src']    = DOKU_BASE.'lib/images/history.png';
-    $p['border'] = 0;
     $p['width']  = 12;
     $p['height'] = 14;
     $p['title']  = $lang['btn_revs'];
@@ -500,8 +532,8 @@ function html_recent($first=0){
     print '</a> ';
 
     print html_wikilink(':'.$recent['id'],$conf['useheading']?NULL:$recent['id']);
-
     print ' '.htmlspecialchars($recent['sum']);
+
     print ' <span class="user">';
     if($recent['user']){
       print $recent['user'];
@@ -510,6 +542,7 @@ function html_recent($first=0){
     }
     print '</span>';
 
+    print '</div>';
     print '</li>';
   }
   print '</ul>';
@@ -517,7 +550,7 @@ function html_recent($first=0){
   print '<div class="pagenav">';
   $last = $first + $conf['recent'];
   if ($first > 0) {
-    $first -= $conf['recent']; 
+    $first -= $conf['recent'];
     if ($first < 0) $first = 0;
     print '<div class="pagenav-prev">';
     print html_btn('newer','',"p",array('do' => 'recent', 'first' => $first));
@@ -615,6 +648,9 @@ function html_li_default($item){
  * print the <li> tag. Both user function need to accept
  * a single item.
  *
+ * Both user functions can be given as array to point to
+ * a member of an object.
+ *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function html_buildlist($data,$class,$func,$lifunc='html_li_default'){
@@ -642,14 +678,22 @@ function html_buildlist($data,$class,$func,$lifunc='html_li_default'){
       $ret .= "</li>\n";
     }
 
-    //remember current level 
+    //remember current level
     $level = $item['level'];
 
     //print item
-    $ret .= $lifunc($item); //user function
-    $ret .= '<span class="li">';
+    if(is_array($lifunc)){
+      $ret .= $lifunc[0]->$lifunc[1]($item); //user object method
+    }else{
+      $ret .= $lifunc($item); //user function
+    }
+    $ret .= '<div class="li">';
+    if(is_array($func)){
+      $ret .= $func[0]->$func[1]($item); //user object method
+    }else{
     $ret .= $func($item); //user function
-    $ret .= '</span>';
+    }
+    $ret .= '</div>';
   }
 
   //close remaining items and lists
@@ -676,9 +720,9 @@ function html_backlinks(){
 
   print '<ul class="idx">';
   foreach($data as $blink){
-    print '<li>';
+    print '<li><div class="li">';
     print html_wikilink(':'.$blink,$conf['useheading']?NULL:$blink);
-    print '</li>';
+    print '</div></li>';
   }
   print '</ul>';
 }
@@ -721,14 +765,14 @@ function html_diff($text='',$intro=true){
   $tdf = new TableDiffFormatter();
   if($intro) print p_locale_xhtml('diff');
   ?>
-    <table class="diff" width="100%">
+    <table class="diff">
       <tr>
-        <td colspan="2" width="50%" class="diff-header">
+        <th colspan="2">
           <?php echo $left?>
-        </td>
-        <td colspan="2" width="50%" class="diff-header">
+        </th>
+        <th colspan="2">
           <?php echo $right?>
-        </td>
+        </th>
       </tr>
       <?php echo $tdf->format($df)?>
     </table>
@@ -746,12 +790,12 @@ function html_conflict($text,$summary){
 
   print p_locale_xhtml('conflict');
   ?>
-  <form name="editform" method="post" action="<?php echo script()?>" accept-charset="<?php echo $lang['encoding']?>">
-  <input type="hidden" name="id" value="<?php echo $ID?>" />
-  <input type="hidden" name="wikitext" value="<?php echo formText($text)?>" />
-  <input type="hidden" name="summary" value="<?php echo formText($summary)?>" />
-  
-  <div align="center">
+  <form id="dw__editform" method="post" action="<?php echo script()?>" accept-charset="<?php echo $lang['encoding']?>">
+  <div class="centeralign">
+    <input type="hidden" name="id" value="<?php echo $ID?>" />
+    <input type="hidden" name="wikitext" value="<?php echo formText($text)?>" />
+    <input type="hidden" name="summary" value="<?php echo formText($summary)?>" />
+
     <input class="button" type="submit" name="do" value="<?php echo $lang['btn_save']?>" accesskey="s" title="[ALT+S]" />
     <input class="button" type="submit" name="do" value="<?php echo $lang['btn_cancel']?>" />
   </div>
@@ -789,25 +833,26 @@ function html_register(){
 
   print p_locale_xhtml('register');
 ?>
-  <div align="center">
-  <form name="register" method="post" action="<?php echo wl($ID)?>" accept-charset="<?php echo $lang['encoding']?>">
-  <input type="hidden" name="do" value="register" />
-  <input type="hidden" name="save" value="1" />
+  <div class="centeralign">
+  <form id="dw__register" method="post" action="<?php echo wl($ID)?>" accept-charset="<?php echo $lang['encoding']?>">
   <fieldset>
+    <input type="hidden" name="do" value="register" />
+    <input type="hidden" name="save" value="1" />
+
     <legend><?php echo $lang['register']?></legend>
-    <label>
+    <label class="block">
       <?php echo $lang['user']?>
       <input type="text" name="login" class="edit" size="50" value="<?php echo formText($_POST['login'])?>" />
     </label><br />
-    
+
     <?php
       if (!$conf['autopasswd']) {
     ?>
-      <label>
+      <label class="block">
         <?php echo $lang['pass']?>
         <input type="password" name="pass" class="edit" size="50" />
       </label><br />
-      <label>
+      <label class="block">
         <?php echo $lang['passchk']?>
         <input type="password" name="passchk" class="edit" size="50" />
       </label><br />
@@ -815,11 +860,11 @@ function html_register(){
       }
     ?>
 
-    <label>
+    <label class="block">
       <?php echo $lang['fullname']?>
       <input type="text" name="fullname" class="edit" size="50" value="<?php echo formText($_POST['fullname'])?>" />
     </label><br />
-    <label>
+    <label class="block">
       <?php echo $lang['email']?>
       <input type="text" name="email" class="edit" size="50" value="<?php echo formText($_POST['email'])?>" />
     </label><br />
@@ -830,6 +875,71 @@ function html_register(){
 <?php
 }
 
+/**
+ * Print the update profile form
+ *
+ * @author Christopher Smith <chris@jalakai.co.uk>
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+function html_updateprofile(){
+  global $lang;
+  global $conf;
+  global $ID;
+  global $INFO;
+  global $auth;
+
+  print p_locale_xhtml('updateprofile');
+
+  if (empty($_POST['fullname'])) $_POST['fullname'] = $INFO['userinfo']['name'];
+  if (empty($_POST['email'])) $_POST['email'] = $INFO['userinfo']['mail'];
+?>
+  <div class="centeralign">
+  <form id="dw__register" method="post" action="<?php echo wl($ID)?>" accept-charset="<?php echo $lang['encoding']?>">
+  <fieldset style="width: 80%;">
+    <input type="hidden" name="do" value="profile" />
+    <input type="hidden" name="save" value="1" />
+
+    <legend><?php echo $lang['profile']?></legend>
+    <label class="block">
+      <?php echo $lang['user']?>
+      <input type="text" name="fullname" disabled="disabled" class="edit" size="50" value="<?php echo formText($_SERVER['REMOTE_USER'])?>" />
+    </label><br />
+    <label class="block">
+      <?php echo $lang['fullname']?>
+      <input type="text" name="fullname" <?php if(!$auth->canDo('modName')) echo 'disabled="disabled"'?> class="edit" size="50" value="<?php echo formText($_POST['fullname'])?>" />
+    </label><br />
+    <label class="block">
+      <?php echo $lang['email']?>
+      <input type="text" name="email" <?php if(!$auth->canDo('modName')) echo 'disabled="disabled"'?> class="edit" size="50" value="<?php echo formText($_POST['email'])?>" />
+    </label><br /><br />
+
+    <?php if($auth->canDo('modPass')) { ?>
+    <label class="block">
+      <?php echo $lang['newpass']?>
+      <input type="password" name="newpass" class="edit" size="50" />
+    </label><br />
+    <label class="block">
+      <?php echo $lang['passchk']?>
+      <input type="password" name="passchk" class="edit" size="50" />
+    </label><br />
+    <?php } ?>
+
+    <?php if ($conf['profileconfirm']) { ?>
+      <br />
+      <label class="block">
+      <?php echo $lang['oldpass']?>
+      <input type="password" name="oldpass" class="edit" size="50" />
+    </label><br />
+    <?php } ?>
+
+    <input type="submit" class="button" value="<?php echo $lang['btn_save']?>" />
+    <input type="reset" class="button" value="<?php echo $lang['btn_reset']?>" />
+  </fieldset>
+  </form>
+  </div>
+<?php
+}
+
 /**
  * This displays the edit form (lots of logic included)
  *
@@ -884,113 +994,81 @@ function html_edit($text=null,$include='edit'){ //FIXME: include needed?
   }
   if(!$DATE) $DATE = $INFO['lastmod'];
 
-  
+
 ?>
-  <form name="editform" method="post" action="<?php echo script()?>" accept-charset="<?php echo $lang['encoding']?>" onsubmit="return svchk()">
-  <input type="hidden" name="id"   value="<?php echo $ID?>" />
-  <input type="hidden" name="rev"  value="<?php echo $REV?>" />
-  <input type="hidden" name="date" value="<?php echo $DATE?>" />
-  <input type="hidden" name="prefix" value="<?php echo formText($PRE)?>" />
-  <input type="hidden" name="suffix" value="<?php echo formText($SUF)?>" />
-  <table style="width:99%">
-    <tr>
-      <td class="toolbar" colspan="2">
+  <div style="width:99%;">
+  <form id="dw__editform" method="post" action="<?php echo script()?>" accept-charset="<?php echo $lang['encoding']?>"><div class="no">
+     <div class="toolbar">
+        <div id="tool__bar"></div>
+        <input type="hidden" name="id"   value="<?php echo $ID?>" />
+        <input type="hidden" name="rev"  value="<?php echo $REV?>" />
+        <input type="hidden" name="date" value="<?php echo $DATE?>" />
+        <input type="hidden" name="prefix" value="<?php echo formText($PRE)?>" />
+        <input type="hidden" name="suffix" value="<?php echo formText($SUF)?>" />
+
         <?php if($wr){?>
-        <script language="javascript" type="text/javascript" charset="utf-8">
+        <script type="text/javascript" charset="utf-8">
           <?php /* sets changed to true when previewed */?>
           textChanged = <?php ($pr) ? print 'true' : print 'false' ?>;
-          
-          formatButton('bold.png','<?php echo $lang['qb_bold']?>','**','**','<?php echo $lang['qb_bold']?>','b');
-          formatButton('italic.png','<?php echo $lang['qb_italic']?>',"\/\/","\/\/",'<?php echo $lang['qb_italic']?>','i');
-          formatButton('underline.png','<?php echo $lang['qb_underl']?>','__','__','<?php echo $lang['qb_underl']?>','u');
-          formatButton('code.png','<?php echo $lang['qb_code']?>','\'\'','\'\'','<?php echo $lang['qb_code']?>','c');
-          formatButton('strike.png','<?php echo $lang['qb_strike']?>','&lt;del&gt;','&lt;\/del&gt;','<?php echo $lang['qb_strike']?>','d');
-
-          formatButton('fonth1.png','<?php echo $lang['qb_h1']?>','====== ',' ======\n','<?php echo $lang['qb_h1']?>','1');
-          formatButton('fonth2.png','<?php echo $lang['qb_h2']?>','===== ',' =====\n','<?php echo $lang['qb_h2']?>','2');
-          formatButton('fonth3.png','<?php echo $lang['qb_h3']?>','==== ',' ====\n','<?php echo $lang['qb_h3']?>','3');
-          formatButton('fonth4.png','<?php echo $lang['qb_h4']?>','=== ',' ===\n','<?php echo $lang['qb_h4']?>','4');
-          formatButton('fonth5.png','<?php echo $lang['qb_h5']?>','== ',' ==\n','<?php echo $lang['qb_h5']?>','5');
-
-          formatButton('link.png','<?php echo $lang['qb_link']?>','[[',']]','<?php echo $lang['qb_link']?>','l');
-          formatButton('extlink.png','<?php echo $lang['qb_extlink']?>','[[',']]','http://www.example.com|<?php echo $lang['qb_extlink']?>');
-
-          formatButton('list.png','<?php echo $lang['qb_ol']?>','  - ','\n','<?php echo $lang['qb_ol']?>');
-          formatButton('list_ul.png','<?php echo $lang['qb_ul']?>','  * ','\n','<?php echo $lang['qb_ul']?>');
-
-          insertButton('rule.png','<?php echo $lang['qb_hr']?>','----\n');
-          mediaButton('image.png','<?php echo $lang['qb_media']?>','m','<?php echo $INFO['namespace']?>');
-
-          <?php
-          if($conf['useacl'] && $_SERVER['REMOTE_USER']){
-            echo "insertButton('sig.png','".$lang['qb_sig']."','".html_signature()."','y');";
-          }
-          ?>
         </script>
-        <span id="spell_action"></span>
+        <span id="spell__action"></span>
         <?php } ?>
-      </td>
-      <td>
-        <div id="spell_suggest"></div>
-      </td>
-    </tr>
-    <tr>
-      <td colspan="3">
-        <div id="spell_result"></div>
-        <textarea name="wikitext" id="wikitext" <?php echo $ro?> cols="80" rows="10" class="edit" onchange="textChanged = true;" onkeyup="summaryCheck();" tabindex="1"><?php echo "\n".formText($text)?></textarea>
-      </td>
-    </tr>
-    <tr id="wikieditbar">
-      <td>
+        <div id="spell__suggest"></div>
+    </div>
+    <div id="spell__result"></div>
+
+    <textarea name="wikitext" id="wiki__text" <?php echo $ro?> cols="80" rows="10" class="edit" tabindex="1"><?php echo "\n".formText($text)?></textarea>
+
+    <div id="wiki__editbar">
+      <div id="size__ctl"></div>
       <?php if($wr){?>
-        <input class="button" type="submit" name="do" value="<?php echo $lang['btn_save']?>" accesskey="s" title="[ALT+S]" onclick="textChanged=false" onkeypress="textChanged=false" tabindex="3" />
-        <input class="button" type="submit" name="do" value="<?php echo $lang['btn_preview']?>" accesskey="p" title="[ALT+P]" onclick="textChanged=false" onkeypress="textChanged=false" tabindex="4" />
-        <input class="button" type="submit" name="do" value="<?php echo $lang['btn_cancel']?>" tabindex="5" />
+         <div class="editButtons">
+            <input class="button" id="edbtn__save" type="submit" name="do" value="<?php echo $lang['btn_save']?>" accesskey="s" title="[ALT+S]" tabindex="4" />
+            <input class="button" id="edbtn__preview" type="submit" name="do" value="<?php echo $lang['btn_preview']?>" accesskey="p" title="[ALT+P]" tabindex="5" />
+            <input class="button" type="submit" name="do" value="<?php echo $lang['btn_cancel']?>" tabindex="5" />
+         </div>
       <?php } ?>
-      </td>
-      <td>
       <?php if($wr){ ?>
-        <?php echo $lang['summary']?>:
-        <input type="text" class="edit" name="summary" id="summary" size="50" onkeyup="summaryCheck();" value="<?php echo formText($SUM)?>" tabindex="2" />
+        <div class="summary">
+           <label for="edit__summary" class="nowrap"><?php echo $lang['summary']?>:</label>
+           <input type="text" class="edit" name="summary" id="edit__summary" size="50" value="<?php echo formText($SUM)?>" tabindex="2" />
+           <?php html_minoredit()?>
+        </div>
       <?php }?>
-      </td>
-      <td align="right">
-        <script language="javascript" type="text/javascript" charset="utf-8">
-          showSizeCtl();
-          <?php if($wr){ ?>
-            init_locktimer(<?php echo $conf['locktime']-60?>,'<?php echo $lang['willexpire']?>');
-
-            //initialize spellchecker
-            <?php if($conf['spellchecker']){ ?>
-              ajax_spell.init('<?php echo $lang['spell_start']?>','<?php echo $lang['spell_stop']?>','<?php echo $lang['spell_wait']?>','<?php echo $lang['spell_noerr']?>','<?php echo $lang['spell_nosug']?>','<?php echo $lang['spell_change']?>');
-            <?php } ?>
-
-            document.editform.wikitext.focus();
-          <?php } ?>
-        </script>
-      </td>
-    </tr>
-  </table>
-  </form>
+    </div>
+  </div></form>
+  </div>
 <?php
 }
 
 /**
- * prepares the signature string as configured in the config
+ * Adds a checkbox for minor edits for logged in users
  *
- * @author Andreas Gohr <andi@splitbrain.org>
+ * @author Andrea Gohr <andi@splitbrain.org>
  */
-function html_signature(){
+function html_minoredit(){
   global $conf;
-  global $INFO;
+  global $lang;
+  // minor edits are for logged in users only
+  if(!$conf['useacl'] || !$_SERVER['REMOTE_USER']){
+    return;
+  }
 
-  $sig = $conf['signature'];
-  $sig = strftime($sig);
-  $sig = str_replace('@USER@',$_SERVER['REMOTE_USER'],$sig);
-  $sig = str_replace('@NAME@',$INFO['userinfo']['name'],$sig);
-  $sig = str_replace('@MAIL@',$INFO['userinfo']['mail'],$sig);
-  $sig = str_replace('@DATE@',date($conf['dformat']),$sig);
-  return addslashes($sig);
+  $p = array();
+  $p['name']     = 'minor';
+  $p['type']     = 'checkbox';
+  $p['id']       = 'minoredit';
+  $p['tabindex'] = 3;
+  $p['value']    = '1';
+  if($_REQUEST['minor']) $p['checked']='checked';
+  $att = buildAttributes($p);
+
+  print '<span class="nowrap">';
+  print "<input $att />";
+  print '<label for="minoredit">';
+  print $lang['minoredit'];
+  print '</label>';
+  print '</span>';
 }
 
 /**
@@ -1001,6 +1079,7 @@ function html_signature(){
 function html_debug(){
   global $conf;
   global $lang;
+  global $auth;
   //remove sensitive data
   $cnf = $conf;
   $cnf['auth']='***';
@@ -1024,11 +1103,11 @@ function html_debug(){
   print '<b>DOKU_BASE:</b><pre>';
   print DOKU_BASE;
   print '</pre>';
-  
+
   print '<b>abs DOKU_BASE:</b><pre>';
   print DOKU_URL;
   print '</pre>';
-  
+
   print '<b>rel DOKU_BASE:</b><pre>';
   print dirname($_SERVER['PHP_SELF']).'/';
   print '</pre>';
@@ -1045,6 +1124,16 @@ function html_debug(){
   print $lang['encoding'];
   print '</pre>';
 
+  if($auth){
+    print '<b>Auth backend capabilities:</b><pre>';
+    print_r($auth->cando);
+    print '</pre>';
+  }
+
+  print '<b>$_SESSION:</b><pre>';
+  print_r($_SESSION);
+  print '</pre>';
+
   print '<b>Environment:</b><pre>';
   print_r($_ENV);
   print '</pre>';
@@ -1069,7 +1158,7 @@ function html_admin(){
   $menu = array();
   foreach ($pluginlist as $p) {
     if($obj =& plugin_load('admin',$p) === NULL) continue;
-    $menu[] = array('plugin' => $p, 
+    $menu[] = array('plugin' => $p,
                     'prompt' => $obj->getMenuText($conf['lang']),
                     'sort' => $obj->getMenuSort()
                    );
@@ -1082,28 +1171,45 @@ function html_admin(){
 
   foreach ($menu as $item) {
     if (!$item['prompt']) continue;
-    ptln('  <li><a href="'.wl($ID, 'do=admin&amp;page='.$item['plugin']).'">'.$item['prompt'].'</a></li>');
+    ptln('  <li><div class="li"><a href="'.wl($ID, 'do=admin&amp;page='.$item['plugin']).'">'.$item['prompt'].'</a></div></li>');
   }
 
   // add in non-plugin functions
   if (!$conf['openregister']){
-    ptln('<li><a href="'.wl($ID,'do=register').'">'.$lang['admin_register'].'</a></li>');
+    ptln('<li><div class="li"><a href="'.wl($ID,'do=register').'">'.$lang['admin_register'].'</a></div></li>');
   }
-  
-  ptln('</ul>');
 
-/*
-  ptln('<ul>');  ptln('<ul class="admin">');
-
-  // currently ACL only - more to come
-  ptln('<li><a href="'.wl($ID,'do=admin&amp;page=acl').'">'.$lang['admin_acl'].'</a></li>');
-  if (!$conf['openregister']){
-    ptln('<li><a href="'.wl($ID,'do=register').'">'.$lang['admin_register'].'</a></li>');
-  }
-    
   ptln('</ul>');
-*/
 }
 
+/**
+ * Form to request a new password for an existing account
+ *
+ * @author Benoit Chesneau <benoit@bchesneau.info>
+ */
+function html_resendpwd() {
+  global $lang;
+  global $conf;
+  global $ID;
+
+  print p_locale_xhtml('resendpwd');
+?>
+  <div class="centeralign">
+  <form id="dw__resendpwd" action="<?php echo wl($ID)?>" accept-charset="<?php echo $lang['encoding']?>" method="post">
+    <fieldset>
+      <br />
+      <legend><?php echo $lang['resendpwd']?></legend>
+      <input type="hidden" name="do" value="resendpwd" />
+      <input type="hidden" name="save" value="1" />
+      <label class="block">
+        <span><?php echo $lang['user']?></span>
+        <input type="text" name="login" value="<?php echo formText($_POST['login'])?>" class="edit" /><br /><br />
+      </label><br />
+      <input type="submit" value="<?php echo $lang['btn_resendpwd']?>" class="button" />
+    </fieldset>
+  </form>
+  </div>
+<?php
+}
 
 //Setup VIM: ex: et ts=2 enc=utf-8 :
