@@ -18,7 +18,9 @@
 
   // load the config file(s)
   require_once(DOKU_CONF.'dokuwiki.php');
-  @include_once(DOKU_CONF.'local.php');
+  if(@file_exists(DOKU_CONF.'local.php')){
+    require_once(DOKU_CONF.'local.php');
+  }
 
   //prepare language array
   global $lang;
@@ -26,7 +28,9 @@
 
   //load the language files
   require_once(DOKU_INC.'inc/lang/en/lang.php');
-  require_once(DOKU_INC.'inc/lang/'.$conf['lang'].'/lang.php');
+  if ( $conf['lang'] && $conf['lang'] != 'en' ) {
+    require_once(DOKU_INC.'inc/lang/'.$conf['lang'].'/lang.php');
+  }
 
   // define baseURL
   if(!defined('DOKU_BASE')) define('DOKU_BASE',getBaseURL());
@@ -42,21 +46,28 @@
   if(!defined('DOKU_TPL')) define('DOKU_TPL',
                                   DOKU_BASE.'lib/tpl/'.$conf['template'].'/');
 
+  // define real Template directory
+  if(!defined('DOKU_TPLINC')) define('DOKU_TPLINC',
+                                  DOKU_INC.'lib/tpl/'.$conf['template'].'/');
+
   // make session rewrites XHTML compliant
   @ini_set('arg_separator.output', '&amp;');
 
   // init session
-  session_name("DokuWiki");
-  if (!headers_sent()) session_start();
+  if (!headers_sent() && !defined('NOSESSION')){
+    session_name("DokuWiki");
+    session_start();
+  }
 
   // kill magic quotes
-  if (get_magic_quotes_gpc()) {
+  if (get_magic_quotes_gpc() && !defined('MAGIC_QUOTES_STRIPPED')) {
     if (!empty($_GET))    remove_magic_quotes($_GET);
     if (!empty($_POST))   remove_magic_quotes($_POST);
     if (!empty($_COOKIE)) remove_magic_quotes($_COOKIE);
     if (!empty($_REQUEST)) remove_magic_quotes($_REQUEST);
-    if (!empty($_SESSION)) remove_magic_quotes($_SESSION);
+#    if (!empty($_SESSION)) remove_magic_quotes($_SESSION); #FIXME needed ?
     @ini_set('magic_quotes_gpc', 0);
+    define('MAGIC_QUOTES_STRIPPED',1);
   }
   @set_magic_quotes_runtime(0);
   @ini_set('magic_quotes_sybase',0);
@@ -66,8 +77,8 @@
     $conf['usegzip'] = 0;
   }
 
-  // remember original umask
-  $conf['oldumask'] = umask();
+  // precalculate file creation modes
+  init_creationmodes();
 
   // make real paths and check them
   init_paths();
@@ -95,38 +106,94 @@ function init_paths(){
   foreach($paths as $c => $p){
     if(!$conf[$c])   $conf[$c] = $conf['savedir'].'/'.$p;
     $conf[$c]        = init_path($conf[$c]);
-    if(!$conf[$c])   die("$c does not exist or isn't writable. Check config!");
+    if(!$conf[$c])   nice_die("The $c does not exist, isn't accessable or writable.
+                               Check your config and permission settings!");
   }
 }
 
 /**
- * Checks the existance of certain files and creates them if missing
+ * Checks the existance of certain files and creates them if missing.
  */
 function init_files(){
   global $conf;
+
   $files = array( $conf['cachedir'].'/word.idx',
                   $conf['cachedir'].'/page.idx',
-                  $conf['cachedir'].'/index.idx', );
+                  $conf['cachedir'].'/index.idx');
 
   foreach($files as $file){
     if(!@file_exists($file)){
-      $fh = fopen($file,'a');
-      fclose($fh);
+      $fh = @fopen($file,'a');
+      if($fh){
+        fclose($fh);
+        if($conf['fperm']) chmod($file, $conf['fperm']);
+      }else{
+        nice_die("$file is not writable. Check your permissions settings!");
+      }
     }
   }
 }
 
 /**
- * returns absolute path
+ * Returns absolute path
  *
- * This tries the given path first, then checks in DOKU_INC
+ * This tries the given path first, then checks in DOKU_INC.
+ * Check for accessability on directories as well.
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
  */
 function init_path($path){
+  // check existance
   $p = realpath($path);
-  if(@file_exists($p)) return $p;
-  $p = realpath(DOKU_INC.$path);
-  if(@file_exists($p)) return $p;
-  return '';
+  if(!@file_exists($p)){
+    $p = realpath(DOKU_INC.$path);
+    if(!@file_exists($p)){
+      return '';
+    }
+  }
+
+  // check writability
+  if(!@is_writable($p)){
+    return '';
+  }
+
+  // check accessability (execute bit) for directories
+  if(@is_dir($p) && !@file_exists("$p/.")){
+    return '';
+  }
+
+  return $p;
+}
+
+/**
+ * Sets the internal config values fperm and dperm which, when set,
+ * will be used to change the permission of a newly created dir or
+ * file with chmod. Considers the influence of the system's umask
+ * setting the values only if needed.
+ */
+function init_creationmodes(){
+  global $conf;
+
+  // Legacy support for old umask/dmask scheme
+  unset($conf['dmask']);
+  unset($conf['fmask']);
+  unset($conf['umask']);
+  unset($conf['fperm']);
+  unset($conf['dperm']);
+
+  // get system umask, fallback to 0 if none available
+  $umask = @umask();
+  if(!$umask) $umask = 0000;
+
+  // check what is set automatically by the system on file creation
+  // and set the fperm param if it's not what we want
+  $auto_fmode = 0666 & ~$umask;
+  if($auto_fmode != $conf['fmode']) $conf['fperm'] = $conf['fmode'];
+
+  // check what is set automatically by the system on file creation
+  // and set the dperm param if it's not what we want
+  $auto_dmode = $conf['dmode'] & ~$umask;
+  if($auto_dmode != $conf['dmode']) $conf['dperm'] = $conf['dmode'];
 }
 
 /**
@@ -157,19 +224,21 @@ function getBaseURL($abs=false){
 
   if($conf['basedir']){
     $dir = $conf['basedir'].'/';
-  }elseif($_SERVER['SCRIPT_NAME']){
+  }elseif(substr($_SERVER['SCRIPT_NAME'],-4) == '.php'){
     $dir = dirname($_SERVER['SCRIPT_NAME']).'/';
+  }elseif(substr($_SERVER['PHP_SELF'],-4) == '.php'){
+    $dir = dirname($_SERVER['PHP_SELF']).'/';
   }elseif($_SERVER['DOCUMENT_ROOT'] && $_SERVER['SCRIPT_FILENAME']){
     $dir = preg_replace ('/^'.preg_quote($_SERVER['DOCUMENT_ROOT'],'/').'/','',
                          $_SERVER['SCRIPT_FILENAME']);
     $dir = dirname('/'.$dir).'/';
   }else{
-    $dir = dirname($_SERVER['PHP_SELF']).'/';
+    $dir = './'; //probably wrong
   }
 
   $dir = str_replace('\\','/',$dir); #bugfix for weird WIN behaviour
   $dir = preg_replace('#//+#','/',$dir);
-  
+
   //handle script in lib/exe dir
   $dir = preg_replace('!lib/exe/$!','',$dir);
 
@@ -223,7 +292,7 @@ function scriptify($file) {
   }
   $fh = fopen($fn, 'w');
   if (!$fh) {
-    die($fn.' is not writable!');
+    nice_die($fn.' is not writable. Check your permission settings!');
   }
   // write php exit hack first
   fwrite($fh, "# $fn\n");
@@ -240,5 +309,26 @@ function scriptify($file) {
   @rename($file,"$file.old");
 }
 
+/**
+ * print a nice message even if no styles are loaded yet.
+ */
+function nice_die($msg){
+  echo<<<EOT
+  <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+   "http://www.w3.org/TR/html4/loose.dtd">
+  <html>
+    <head><title>DokuWiki Setup Error</title></head>
+    <body style="font-family: Arial, sans-serif">
+      <div style="width:60%; margin: auto; background-color: #fcc;
+                  border: 1px solid #faa; padding: 0.5em 1em;">
+      <h1 style="font-size: 120%">DokuWiki Setup Error</h1>
+      <p>$msg</p>
+      </div>
+    </body>
+  </html>
+EOT;
+  exit;
+}
+
 
 //Setup VIM: ex: et ts=2 enc=utf-8 :
