@@ -16,13 +16,12 @@
  * @todo use safemode hack
  * @author  Andreas Gohr <andi@splitbrain.org>
  */
-function io_sweepNS($id){
+function io_sweepNS($id,$basedir='datadir'){
   global $conf;
 
   //scan all namespaces
   while(($id = getNS($id)) !== false){
-		$dir = $conf['datadir'].'/'.str_replace(':','/',$id);
-    $dir = utf8_encodeFN($dir);
+    $dir = $conf[$basedir].'/'.utf8_encodeFN(str_replace(':','/',$id));
 
     //try to delete dir else return
     if(!@rmdir($dir)) return;
@@ -36,7 +35,7 @@ function io_sweepNS($id){
  *
  * @author  Andreas Gohr <andi@splitbrain.org>
  */
-function io_readFile($file){
+function io_readFile($file,$clean=true){
   $ret = '';
   if(@file_exists($file)){
     if(substr($file,-3) == '.gz'){
@@ -45,7 +44,11 @@ function io_readFile($file){
       $ret = join('',file($file));
     }
   }
-  return cleanText($ret);
+  if($clean){
+    return cleanText($ret);
+  }else{
+    return $ret;
+  }
 }
 
 /**
@@ -60,8 +63,10 @@ function io_readFile($file){
  * @return bool true on success
  */
 function io_saveFile($file,$content,$append=false){
+  global $conf;
   $mode = ($append) ? 'ab' : 'wb';
 
+  $fileexists = file_exists($file);
   io_makeFileDir($file);
   io_lock($file);
   if(substr($file,-3) == '.gz'){
@@ -81,6 +86,8 @@ function io_saveFile($file,$content,$append=false){
     fwrite($fh, $content);
     fclose($fh);
   }
+
+  if(!$fileexists and $conf['fperm']) chmod($file, $conf['fperm']);
   io_unlock($file);
   return true;
 }
@@ -92,10 +99,12 @@ function io_saveFile($file,$content,$append=false){
  *
  * Uses gzip if extension is .gz
  *
+ * 2005-10-14 : added regex option -- Christopher Smith <chris@jalakai.co.uk>
+ *
  * @author Steven Danz <steven-danz@kc.rr.com>
  * @return bool true on success
  */
-function io_deleteFromFile($file,$badline){
+function io_deleteFromFile($file,$badline,$regex=false){
   if (!@file_exists($file)) return true;
 
   io_lock($file);
@@ -108,10 +117,14 @@ function io_deleteFromFile($file,$badline){
   }
 
   // remove all matching lines
-  $pos = array_search($badline,$lines); //return null or false if not found
-  while(is_int($pos)){
-    unset($lines[$pos]);
-    $pos = array_search($badline,$lines);
+  if ($regex) {
+    $lines = preg_grep($badline,$lines,PREG_GREP_INVERT);
+  } else {
+    $pos = array_search($badline,$lines); //return null or false if not found
+    while(is_int($pos)){
+      unset($lines[$pos]);
+      $pos = array_search($badline,$lines);
+    }
   }
 
   if(count($lines)){
@@ -148,7 +161,7 @@ function io_deleteFromFile($file,$badline){
  * inside $conf['lockdir']
  *
  * It waits maximal 3 seconds for the lock, after this time
- * the lock is assumed to be stale and the function goes on 
+ * the lock is assumed to be stale and the function goes on
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
@@ -160,12 +173,12 @@ function io_lock($file){
   $lockDir = $conf['lockdir'].'/'.md5($file);
   @ignore_user_abort(1);
 
-  
   $timeStart = time();
   do {
     //waited longer than 3 seconds? -> stale lock
     if ((time() - $timeStart) > 3) break;
-    $locked = @mkdir($lockDir);
+    $locked = @mkdir($lockDir, $conf['dmode']);
+    if($locked && $conf['dperm']) chmod($lockDir, $conf['dperm']);
   } while ($locked === false);
 }
 
@@ -193,11 +206,9 @@ function io_makeFileDir($file){
   global $conf;
 
   $dir = dirname($file);
-  umask($conf['dmask']);
-  if(!is_dir($dir)){
+  if(!@is_dir($dir)){
     io_mkdir_p($dir) || msg("Creating directory $dir failed",-1);
   }
-  umask($conf['umask']); 
 }
 
 /**
@@ -209,7 +220,7 @@ function io_makeFileDir($file){
  */
 function io_mkdir_p($target){
   global $conf;
-  if (is_dir($target)||empty($target)) return 1; // best case check first
+  if (@is_dir($target)||empty($target)) return 1; // best case check first
   if (@file_exists($target) && !is_dir($target)) return 0;
   //recursion
   if (io_mkdir_p(substr($target,0,strrpos($target,'/')))){
@@ -217,7 +228,9 @@ function io_mkdir_p($target){
       $dir = preg_replace('/^'.preg_quote(realpath($conf['ftp']['root']),'/').'/','', $target);
       return io_mkdir_ftp($dir);
     }else{
-      return @mkdir($target,0777); // crawl back up & create dir tree
+      $ret = @mkdir($target,$conf['dmode']); // crawl back up & create dir tree
+      if($ret && $conf['dperm']) chmod($target, $conf['dperm']);
+      return $ret;
     }
   }
   return 0;
@@ -237,7 +250,7 @@ function io_mkdir_ftp($dir){
     msg("FTP support not found - safemode workaround not usable",-1);
     return false;
   }
-  
+
   $conn = @ftp_connect($conf['ftp']['host'],$conf['ftp']['port'],10);
   if(!$conn){
     msg("FTP connection failed",-1);
@@ -251,8 +264,8 @@ function io_mkdir_ftp($dir){
 
   //create directory
   $ok = @ftp_mkdir($conn, $dir);
-  //set permissions (using the directory umask)
-  @ftp_site($conn,sprintf("CHMOD %04o %s",(0777 - $conf['dmask']),$dir));
+  //set permissions
+  @ftp_site($conn,sprintf("CHMOD %04o %s",$conf['dmode'],$dir));
 
   @ftp_close($conn);
   return $ok;
@@ -261,11 +274,11 @@ function io_mkdir_ftp($dir){
 /**
  * downloads a file from the net and saves it
  *
- * if $useAttachment is false, 
+ * if $useAttachment is false,
  * - $file is the full filename to save the file, incl. path
  * - if successful will return true, false otherwise
- 
- * if $useAttachment is true, 
+
+ * if $useAttachment is true,
  * - $file is the directory where the file should be saved
  * - if successful will return the name used for the saved file, false otherwise
  *
@@ -273,41 +286,65 @@ function io_mkdir_ftp($dir){
  * @author Chris Smith <chris@jalakai.co.uk>
  */
 function io_download($url,$file,$useAttachment=false,$defaultName=''){
+  global $conf;
   $http = new DokuHTTPClient();
   $http->max_bodysize = 2*1024*1024; //max. 2MB
   $http->timeout = 25; //max. 25 sec
 
   $data = $http->get($url);
   if(!$data) return false;
-  
+
   if ($useAttachment) {
     $name = '';
       if (isset($http->resp_headers['content-disposition'])) {
       $content_disposition = $http->resp_headers['content-disposition'];
-      if (is_string($content_disposition) && 
-          preg_match('/attachment;\s*filename\s*=\s*"([^"]*)"/i', $content_disposition, $match=array())) {
-          
+      $match=array();
+      if (is_string($content_disposition) &&
+          preg_match('/attachment;\s*filename\s*=\s*"([^"]*)"/i', $content_disposition, $match)) {
+
           $name = basename($match[1]);
       }
-          
+
     }
-    
+
     if (!$name) {
         if (!$defaultName) return false;
-        $name = $defaultName;        
+        $name = $defaultName;
     }
-    
+
     $file = $file.$name;
   }
 
+  $fileexists = file_exists($file);
   $fp = @fopen($file,"w");
   if(!$fp) return false;
   fwrite($fp,$data);
   fclose($fp);
+  if(!$fileexists and $conf['fperm']) chmod($file, $conf['fperm']);
   if ($useAttachment) return $name;
   return true;
 }
 
+/**
+ * Windows compatible rename
+ *
+ * rename() can not overwrite existing files on Windows
+ * this function will use copy/unlink instead
+ */
+function io_rename($from,$to){
+  global $conf;
+  if(!@rename($from,$to)){
+    if(@copy($from,$to)){
+      if($conf['fperm']) chmod($file, $conf['fperm']);
+      @unlink($from);
+      return true;
+    }
+    return false;
+  }
+  return true;
+}
+
+
 /**
  * Runs an external command and returns it's output as string
  *
@@ -326,5 +363,4 @@ function io_runcmd($cmd){
   return $ret;
 }
 
-
 //Setup VIM: ex: et ts=2 enc=utf-8 :
