@@ -106,20 +106,8 @@ $lang['qb_ul']      = 'Mummuga nimekiri';
 $lang['qb_media']   = 'Lisa pilte ja muid faile';
 $lang['qb_sig']     = 'Lisa allkiri!';
 
-$lang['acl_group']  = 'Grupp';
-$lang['acl_user']   = 'Kasutaja';
-$lang['acl_perms']  = 'Lubatud';
-$lang['page']       = 'leht';
-$lang['namespace']  = 'alajaotus';
-
-$lang['acl_perm1']  = 'Lugemine';
-$lang['acl_perm2']  = 'Toimetamine';
-$lang['acl_perm4']  = 'Tekitamine';
-$lang['acl_perm8']  = 'Üles laadimine';
-$lang['acl_new']    = 'Uue kirje lisamine';
 
 $lang['del_confirm']= 'Kas kustutame selle kirje?';
 
-$lang['admin_acl']  = 'Ligipääsukontrolli nimekirja haldamine...';
 
 //Setup VIM: ex: et ts=2 enc=utf-8 :
