@@ -36,19 +36,27 @@ $lang['btn_admin']  = 'Admin';
 $lang['btn_update'] = 'Mise à jour';
 $lang['btn_delete'] = 'Effacer';
 $lang['btn_back']   = 'Retour';
+$lang['btn_backlink']    = 'Liens vers cette page';
 $lang['btn_backtomedia'] = 'Retour à la sélection du ficher média';
-$lang['btn_subscribe']   = 'Enregistrer les modifications';
-$lang['btn_unsubscribe'] = 'Retirer les modifications';
+$lang['btn_subscribe']   = 'Notifier les modifications';
+$lang['btn_unsubscribe'] = 'Ne pas notifier les modifications';
+$lang['btn_profile']    = 'Mettre à jour le profil';
+$lang['btn_reset']     = 'Réinitialiser';
+$lang['btn_resendpwd'] = 'Envoyer le mot de passe';
 
-$lang['loggedinas'] = 'Se connecter en tant que';
+$lang['loggedinas'] = 'Connecté en tant que';
 $lang['user']       = 'Utilisateur';
 $lang['pass']       = 'Mot de passe';
-$lang['passchk']    = 'encore une fois';
+$lang['newpass']    = 'Nouveau mot de passe';
+$lang['oldpass']    = 'Mot de passe actuel';
+$lang['passchk']    = 'Répéter nouveau mot de passe';
 $lang['remember']   = 'Mémoriser';
 $lang['fullname']   = 'Nom complet';
 $lang['email']      = 'Adresse de courriel';
 $lang['register']   = 'S\'enregistrer';
+$lang['profile']    = 'Profil utilisateur';
 $lang['badlogin']   = 'L\'utilisateur ou le mot de passe est incorrect.';
+$lang['minoredit']  = 'Mineur';
 
 $lang['regmissing'] = 'Désolé, vous devez remplir tous les champs.';
 $lang['reguexists'] = 'Désolé, ce nom d\'utilisateur appartient déjà à un autre utilisateur.';
@@ -60,6 +68,18 @@ $lang['regbadpass'] = 'Les deux mots de passe donnés sont différents, recommen
 $lang['regpwmail']   = 'Votre mot de passe DokuWiki';
 $lang['reghere']     = 'Vous n\'avez pas encore de compte ? Enregistrez-vous ici';
 
+$lang['profna']       = 'Ce wiki ne permet pas de modifier les profils';
+$lang['profnochange'] = 'Pas de changement, rien à faire.';
+$lang['profnoempty']  = 'Un nom ou une adresse de courriel vide n\'est pas permis.';
+$lang['profchanged']  = 'Mise à jour du profil réussie.';
+
+$lang['pwdforget'] = 'Mot de passe oublié ? Faites-vous envoyer votre mot de passe';
+$lang['resendna']  = 'Ce wiki ne permet pas le renvoi de mot de passe.';
+$lang['resendpwd'] = 'Renvoyer le mot de passe de';
+$lang['resendpwdmissing'] = 'Désolé, vous devez remplir tous les champs.';
+$lang['resendpwdnouser']  = 'Désolé, cet utilisateur est introuvable dans notre base.';
+$lang['resendpwdsuccess'] = 'Votre nouveau mot de passe vous a été expédié par courriel.';
+
 $lang['txt_upload'] = 'Sélectionnez un fichier à envoyer';
 $lang['txt_filename'] = 'Donnez un "wikiname" (optionnel)';
 $lang['txt_overwrt']  = 'Remplace le fichier actuel';
@@ -100,19 +120,19 @@ $lang['by']         = 'par';
 $lang['deleted']    = 'effacée';
 $lang['created']    = 'créée';
 $lang['restored']   = 'ancienne révision restaurée';
-$lang['summary']    = 'Résumé des modifications';
+$lang['summary']    = 'Résumé';
 
 $lang['mail_newpage'] = 'page ajoutée :';
 $lang['mail_changed'] = 'page changée :';
 
-$lang['nosmblinks'] = 'Les liens vers les disques partagés de Windows ne fonctionnent qu\'avec Microsoft Internet Explorer.\nVous pouvez toujours faire un copier/coller du lien.';
+$lang['nosmblinks'] = 'Les liens vers les partages Windows ne fonctionnent qu\'avec Microsoft Internet Explorer.\nVous pouvez toujours faire un copier/coller du lien.';
 
 $lang['qb_alert']   = 'SVP, entrez le texte que vous souhaitez formater.\nIl sera ajouté à la fin du document.';
 $lang['qb_bold']    = 'Gras';
 $lang['qb_italic']  = 'Italique';
 $lang['qb_underl']  = 'Souligné';
 $lang['qb_code']    = 'Code';
-$lang['qb_strike']  = 'Texte raturé';
+$lang['qb_strike']  = 'Texte barré';
 $lang['qb_h1']      = 'En-tête 1';
 $lang['qb_h2']      = 'En-tête 2';
 $lang['qb_h3']      = 'En-tête 3';
@@ -122,31 +142,18 @@ $lang['qb_link']    = 'Lien interne';
 $lang['qb_extlink'] = 'Lien externe';
 $lang['qb_hr']      = 'Ligne horizontale';
 $lang['qb_ol']      = 'Liste numérotée';
-$lang['qb_ul']      = 'Liste libre';
+$lang['qb_ul']      = 'Liste à puce';
 $lang['qb_media']   = 'Ajouter des images et autres fichiers';
 $lang['qb_sig']     = 'Insérer une signature';
+$lang['qb_smileys'] = 'Émoticons';
+$lang['qb_chars']   = 'Caractères spéciaux';
 
-$lang['del_confirm']= 'Effacer cette entrée?';
-
-$lang['admin_acl']  = 'Gestion de la liste des contrôles d\'accès';
-$lang['admin_register']= 'Ajouter un nouvel utilisateur...';
-
-$lang['acl_group']  = 'Groupe';
-$lang['acl_user']   = 'Utilisateur';
-$lang['acl_perms']  = 'Permission pour';
-$lang['page']       = 'Page';
-$lang['namespace']  = 'Catégorie';
-
-$lang['acl_perm1']  = 'Lecture';
-$lang['acl_perm2']  = 'Écriture';
-$lang['acl_perm4']  = 'Création';
-$lang['acl_perm8']  = 'Télécharger';
-$lang['acl_perm16'] = 'Effacer';
-$lang['acl_new']    = 'Ajouter une nouvelle entrée';
+$lang['del_confirm']= 'Effacer cette entrée ?';
+$lang['admin_register']= 'Ajouter un nouvel utilisateur';
 
 $lang['spell_start'] = 'Vérifier l\'orthographe';
 $lang['spell_stop']  = 'Reprendre l\'édition';
-$lang['spell_wait']  = 'SVP patienter';
+$lang['spell_wait']  = 'Patientez SVP...';
 $lang['spell_noerr'] = 'Aucune erreur trouvée';
 $lang['spell_nosug'] = 'Pas de suggestion';
 $lang['spell_change']= 'Changer';
@@ -166,4 +173,14 @@ $lang['img_format']  = 'Format';
 $lang['img_camera']  = 'Appareil photo';
 $lang['img_keywords']= 'Mots clef';
 
+$lang['subscribe_success']  = 'Ajout de %s à la liste d\'abonnés de %s';
+$lang['subscribe_error']    = 'Erreur à l\'ajout de %s à la liste d\'abonnés de %s';
+$lang['subscribe_noaddress']= 'Aucune adresse associée à votre nom d\'utilisateur, impossible de vous ajouter à la liste d\'abonnés';
+$lang['unsubscribe_success']= 'Suppression de %s de la liste d\'abonnés de %s';
+$lang['unsubscribe_error']  = 'Erreur à la suppression de %s de la liste d\'abonnés de %s';
+
+/* auth.class language support */
+$lang['authmodfailed']   = 'Mauvais paramétrage de l\'authentification. Merci d\'informer l\'administrateur du Wiki.';
+$lang['authtempfail']    = 'L\'authentification est temporairement indisponible. Si cela perdure, merci d\'informer l\'administrateur du Wiki.';
+
 //Setup VIM: ex: et ts=2 enc=utf-8 :
