@@ -1,10 +1,10 @@
-<?
+<?php
 /**
  * latvian language file
  *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author     Aivars Miška <allefm@gmail.com>
-*/
+ */
 $lang['encoding']   = 'utf-8';
 $lang['direction']  = 'ltr';
 
@@ -16,6 +16,8 @@ $lang['btn_search'] = 'Meklēt';
 $lang['btn_save']   = 'Saglabāt';
 $lang['btn_preview']= 'Priekšskats';
 $lang['btn_top']    = 'Atpakaļ uz sākumu';
+$lang['btn_newer']  = '<< jaunāi';
+$lang['btn_older']  = 'vecāi >>';
 $lang['btn_revs']   = 'Vecās versijas';
 $lang['btn_recent'] = 'Jaunākie grozījumi';
 $lang['btn_upload'] = 'Augšupielādēt';
@@ -27,26 +29,54 @@ $lang['btn_logout'] = 'Iziet';
 $lang['btn_admin']  = 'Administrēt';
 $lang['btn_update'] = 'Atjaunot';
 $lang['btn_delete'] = 'Dzēst';
+$lang['btn_back']   = 'Atpakaļ';
+$lang['btn_backlink']    = "Norādes uz lapu";
+$lang['btn_backtomedia'] = 'Atpakaļ uz mēdiju failu izvēli';
+$lang['btn_subscribe']   = 'Abonēt izmaiņu paziņojumus';
+$lang['btn_unsubscribe'] = 'Atteikties no izmaiņu paziņojumiem';
+$lang['btn_profile']    = 'Labot savu profilu';
+$lang['btn_reset']     = 'Atsaukt izmaiņas';
+$lang['btn_resendpwd'] = 'Nosūtīt jaunu paroli';
 
 $lang['loggedinas'] = 'Pieteicies kā';
 $lang['user']       = 'Lietotājvārds';
 $lang['pass']       = 'Parole';
+$lang['newpass']    = 'Jaunā parole';
+$lang['oldpass']    = 'Atkārto patreizējo paroli';
+$lang['passchk']    = 'vēlreiz';
 $lang['remember']   = 'Atceries mani';
 $lang['fullname']   = 'Pilns vārds';
 $lang['email']      = 'E-pasts';
 $lang['register']   = 'Reģistrēties';
+$lang['profile']    = 'Lietotāja vārds';
 $lang['badlogin']   = 'Atvaino, lietotājvārds vai parole aplama.';
+$lang['minoredit']  = '*! Minor Changes';
 
 $lang['regmissing'] = 'Atvaino, jāaizpilda visas ailes.';
 $lang['reguexists'] = 'Atvaino, tāds lietājs jau ir.';
 $lang['regsuccess'] = 'Lietotājs izveidots. Parole nosūtīta pa pastu.';
+$lang['regsuccess2']= 'Lietotājs izveidots.';
 $lang['regmailfail']= 'Šķiet, ka ir problēmas nosūtīt pastu. Lūdzu sazinies ar administratoru!';
 $lang['regbadmail'] = 'Uzdotā epasta adrese izskatās aplama. Ja tas nav tiesa, sazinies ar administratoru.';
+$lang['regbadpass'] = 'Abas ierakstītās paroles nav vienādas, lūduz atkārto.';
 $lang['regpwmail']  = 'Tava DokuWiki parole';
 $lang['reghere']    = 'Tev vēl nav sava konta? Izveido!';
 
+$lang['profna']       = 'Labot profilu nav iespējams';
+$lang['profnochange'] = 'Izmaiņu nav. Nav, ko darī.';
+$lang['profnoempty']  = 'Bez vārda vai e-pasta adreses nevar.';
+$lang['profchanged']  = 'Profils veiksmīgi izlabots.';
+
+$lang['pwdforget'] = 'Aizmirsi paroli? Saņem jaunu';
+$lang['resendna']  = 'Parolu izsutīšanu nepiedāvāju.';
+$lang['resendpwd'] = 'Nosūtīt jaunu paroli lietotājam';
+$lang['resendpwdmissing'] = 'Atvaino, jāizpilda visas ailes.';
+$lang['resendpwdnouser']  = 'Atvaino, tāda lietotāja nav.';
+$lang['resendpwdsuccess'] = 'Jaunā parole nosūtīta pa e-pastu.';
+
 $lang['txt_upload']   = 'Norādi augšupielādējamo failu';
 $lang['txt_filename'] = 'Ievadi wikivārdu (nav obligāts)';
+$lang['txt_overwrt']  = 'Aizstāt esošo failu';
 $lang['lockedby']     = 'Patlaban bloķējis ';
 $lang['lockexpire']   = 'Bloķējums beigsies ';
 $lang['willexpire']   = 'Tavs bloķējums uz šo lapu pēc minūtes beigsies.\nLai izvairītos no konflikta, nospied Iepriekšapskata pogu\n un bloķējuma laiku sāks skaitīt no jauna.';
@@ -60,9 +90,17 @@ $lang['fileupload']  = 'Mēdiju faila augšupielāde';
 $lang['uploadsucc']  = 'Veiksmīgi ielādēts';
 $lang['uploadfail']  = 'Ielādes kļūme. Varbūt aplamas tiesības?';
 $lang['uploadwrong'] = 'Ielāde aizliegta. Neatļauts faila palšinājums';
+$lang['uploadexist'] = 'Neko nedarīju, jo fails jau ir.';
+$lang['deletesucc']  = 'Fails "%s" dzēsts.';
+$lang['deletefail']  = 'Nevar dzēst "%s". Pārbaudi tiesības.';
+$lang['mediainuse']  = 'Fails "%s" nav izdzēsts, to lieto.';
 $lang['namespaces']  = 'Nodaļas';
 $lang['mediafiles']  = 'Pieejamie faili';
 
+$lang['reference']   = 'Norādes uz failu';
+$lang['ref_inuse']   = 'Failu nevar dzēst, jo izmanto šādas lapas:';
+$lang['ref_hidden']  = 'Dažas norādes ir lapās, ko nav tiesibu skatīt';
+
 $lang['hits']       = 'Apmeklējumi';
 $lang['quickhits']  = 'Atbilstošās lapas';
 $lang['toc']        = 'Satura rādītājs';
@@ -71,6 +109,7 @@ $lang['yours']      = 'Tava versija';
 $lang['diff']       = 'atšķirības no patreizējas versijas';
 $lang['line']       = 'Rinda';
 $lang['breadcrumb'] = 'Ceļš';
+$lang['youarehere'] = 'Tu atrodies šeit';
 $lang['lastmod']    = 'Labota';
 $lang['by']         = ', veicis';
 $lang['deleted']    = 'dzēsts';
@@ -78,8 +117,8 @@ $lang['created']    = 'izveidots';
 $lang['restored']   = 'vecā versija atjaunota';
 $lang['summary']    = 'Anotācija';
 
-$lang['mail_newpage'] = '[DokuWiki] lapa pievienota:';
-$lang['mail_changed'] = '[DokuWiki] lapa mainīta:';
+$lang['mail_newpage'] = 'lapa pievienota:';
+$lang['mail_changed'] = 'lapa mainīta:';
 
 $lang['nosmblinks'] = 'Saites uz Windows resursiem darbojas tikai Microsoft Internet Explorer.\nProtams, ka vari saiti kopēt un iespraust citā programmā.';
 
@@ -88,6 +127,7 @@ $lang['qb_bold']    = 'Trekninājums';
 $lang['qb_italic']  = 'Kursīvs';
 $lang['qb_underl']  = 'Pasvītrojums';
 $lang['qb_code']    = 'Vienplatuma burti';
+$lang['qb_strike']  = 'Pārsvītrots teksts';
 $lang['qb_h1']      = '1. līmeņa virsraksts';
 $lang['qb_h2']      = '2. līmeņa virsraksts';
 $lang['qb_h3']      = '3. līmeņa virsraksts';
@@ -100,21 +140,42 @@ $lang['qb_ol']      = 'Numurēts saraksts';
 $lang['qb_ul']      = 'Nenumurēts saraksts';
 $lang['qb_media']   = 'Pielikt attēlus un citus failus.';
 $lang['qb_sig']     = 'Ievietot parakstu';
+$lang['qb_smileys'] = 'Emotikoni';
+$lang['qb_chars']   = 'Īpašās zīmes';
 
 $lang['del_confirm']= 'Dzēst šo šķirkli?';
+$lang['admin_register']= 'Pievienot jaunu lietotāju';
 
-$lang['admin_acl']  = 'Piekļuves tiesību vadība...';
+$lang['spell_start'] = 'Pārbaudīt pareizrakstību';
+$lang['spell_stop']  = 'Turpināt labošanu';
+$lang['spell_wait']  = 'Lūdzu uzgaidīt...';
+$lang['spell_noerr'] = 'Kļūdu nav';
+$lang['spell_nosug'] = 'Ieteikumu nav';
+$lang['spell_change']= 'Aizstāt';
 
-$lang['acl_group']  = 'Grupa';
-$lang['acl_user']   = 'Lietotājs';
-$lang['acl_perms']  = 'Tiesības';
-$lang['page']       = 'Lapa';
-$lang['namespace']  = 'Nodaļa';
+$lang['metaedit']    = 'Labot metadatus';
+$lang['metasaveerr'] = 'Metadati nav saglabāti';
+$lang['metasaveok']  = 'Metadati saglabāti';
+$lang['img_backto']  = 'Atpakaļ uz';
+$lang['img_title']   = 'Virsraksts';
+$lang['img_caption'] = 'Apraksts';
+$lang['img_date']    = 'Datums';
+$lang['img_fname']   = 'Failvārds';
+$lang['img_fsize']   = 'Izmērs';
+$lang['img_artist']  = 'Fotogrāfs';
+$lang['img_copyr']   = 'Autortiesības';
+$lang['img_format']  = 'Formāts';
+$lang['img_camera']  = 'Fotoaparāts';
+$lang['img_keywords']= 'Atslēgvārdi';
 
-$lang['acl_perm1']  = 'Lasīt';
-$lang['acl_perm2']  = 'Labot';
-$lang['acl_perm4']  = 'Izveidot';
-$lang['acl_perm8']  = 'augšupielādēt';
-$lang['acl_new']    = 'Pievienot jaunu';
+$lang['subscribe_success']  = '%s pievienots  %s abonentu sarakstam';
+$lang['subscribe_error']    = 'Kļūme pievienojot %s  %s abonentu sarakstam';
+$lang['subscribe_noaddress']= 'Nav zināma adrese, ko pievienot abonentu sarakstam';
+$lang['unsubscribe_success']= ' %s svītrots no %s abonentu saraksta';
+$lang['unsubscribe_error']  = 'Kļūme svītrojot %s  no %s abonentu saraksta';
 
-//Setup VIM: ex: et ts=2 enc=utf-8 :
\ No newline at end of file
+/* auth.class language support */
+$lang['authmodfailed']   = 'Aplami konfigurēta lietotāju autentifikācija. Lūdzo ziņo Wiki administratoram.';
+$lang['authtempfail']    = 'Lietotāju autentifikācija pašlaik nedarbojas. Ja tas turpinās ilgstoši, lūduz ziņo Wiki administratoram.';
+
+//Setup VIM: ex: et ts=2 enc=utf-8 :
