@@ -3,8 +3,9 @@
  * Chinese(Simplified) language file
  *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
- * @author     skyroam <skyroam@126.com> 
- * @author     based on tw tranlastion by chinsan <chinsan@mail2000.com.tw>
+ * @author     chinsan <chinsan@mail2000.com.tw>
+ * @author     skyroam <skyroam@126.com>
+ * @author     FXCarl <fxcarl@qq.com>  
  */
 $lang['encoding']   = 'utf-8';
 $lang['direction']  = 'ltr';
@@ -17,40 +18,74 @@ $lang['btn_search'] = '搜寻';
 $lang['btn_save']   = '储存';
 $lang['btn_preview']= '预览';
 $lang['btn_top']    = '回到页顶';
+$lang['btn_newer']  = '<< 较晚更新';
+$lang['btn_older']  = '较早更新 >>';
 $lang['btn_revs']   = '旧版';
 $lang['btn_recent'] = '最近更新';
-$lang['btn_home'] = 'Home';
+$lang['btn_home'] = '主页';
 $lang['btn_upload'] = '上传';
 $lang['btn_cancel'] = '取消';
 $lang['btn_index']  = '索引页';
 $lang['btn_secedit']= '改这段';
 $lang['btn_login']  = '登入';
 $lang['btn_logout'] = '登出';
+$lang['btn_admin']  = '管理';
+$lang['btn_update'] = '更新';
+$lang['btn_delete'] = '删除';
+$lang['btn_back']   = '返回';
+$lang['btn_backlink']    = '后链';
+$lang['btn_backtomedia'] = '返回媒体文件选择';
+$lang['btn_subscribe']   = '已预定的变更';
+$lang['btn_unsubscribe'] = '未预定的变更';
+$lang['btn_profile']    = '更新资料';
+$lang['btn_reset']     = '复位';
+$lang['btn_resendpwd'] = '发送新密码';
 
 $lang['loggedinas'] = '登入为';
 $lang['user']       = '帐号';
 $lang['pass']       = '密码';
+$lang['newpass']    = '新密码';
+$lang['oldpass']    = '确认当前密码';
+$lang['passchk']    = '再来一次';
+$lang['remember']   = '记住我';
 $lang['fullname']   = '昵称';
 $lang['email']      = 'E-Mail';
 $lang['register']   = '注册';
 $lang['badlogin']   = '很抱歉，您的使用者名称或密码可能错误';
 
+$lang['minoredit']  = '小修改';
+
 $lang['regmissing'] = '很抱歉，所有的栏位都要填哦';
 $lang['reguexists'] = '很抱歉，已有人注册该帐号了喔';
 $lang['regsuccess'] = '使用者已建立，密码也以 email 寄出到您信箱了。';
+$lang['regsuccess2']= '这个用户已经存在了的说';
 $lang['regmailfail']= '寄出密码信似乎发生错误，请跟管理者联络！';
 $lang['regbadmail'] = '您给的 email 似乎不对，如果您认为是正确的，请与管理者联络。';
-$lang['regpwmail']  = 'Your DokuWiki Password';
+$lang['regbadpass'] = '两次填入的密码不一致哟，再来一次';
+$lang['regpwmail']  = '你的Wiki登陆密码';
 $lang['reghere']    = '您还没有帐号对吧？来注册一个吧。';
 
+$lang['profna']       = '这里不允许进行资料更新哦';
+$lang['profnochange'] = '没有变化，什么都不用做';
+$lang['profnoempty']  = '不能使用空用户名或空邮件地址哟';
+$lang['profchanged']  = '用户资料更新成功';
+
+$lang['pwdforget'] = '忘记密码了吗? 获取一个新的好了';
+$lang['resendna']  = '这里不支持密码二次发送呢';
+$lang['resendpwd'] = '发送新密码给';
+$lang['resendpwdmissing'] = '对不起，您必须把表格填写完';
+$lang['resendpwdnouser']  = '对不起，我们在数据库中没有发现这个用户';
+$lang['resendpwdsuccess'] = '你的新密码已经通过电子邮件发送到您的信箱';
+
 $lang['txt_upload']   = '选择要上传的档案';
 $lang['txt_filename'] = '输入 wikiname (optional)';
+$lang['txt_overwrt']  = '覆盖现有文件';
 $lang['lockedby']     = '目前已被下列人员锁定';
 $lang['lockexpire']   = '预计解除锁定於';
 $lang['willexpire']   = '您目前编辑这页的锁定将会在一分钟内解除。\若要避免发生意外，请按「预览」键来重新设定锁定状态';
 
 $lang['notsavedyet'] = '有尚未储存的变更将会遗失。\n真的要继续吗？';
-$lang['rssfailed']   = '当抓取它处喂送过来的资料时发生错误: ';
+$lang['rssfailed']   = '抓取外部RSS资料时发生错误: ';
 $lang['nothingfound']= '没找到任何结果。';
 
 $lang['mediaselect'] = '选择影音档';
@@ -58,9 +93,17 @@ $lang['fileupload']  = '上传影音档';
 $lang['uploadsucc']  = '上传成功';
 $lang['uploadfail']  = '上传失败。或许权限设定错误了吗？';
 $lang['uploadwrong'] = '拒绝上传。该档案类型不被支援。';
+$lang['uploadexist'] = '文件已经存在，无须上传咯';
+$lang['deletesucc']  = '文件 "%s" 已经被删除了';
+$lang['deletefail']  = '"%s" 删除失败 - 请检查权限';
+$lang['mediainuse']  = '文件 "%s" 不能被删除 - 正在使用中';
 $lang['namespaces']  = 'Namespaces';
 $lang['mediafiles']  = '可用的档案有';
 
+$lang['reference']   = '参考信息';
+$lang['ref_inuse']   = '文件不能被删除, 以下页面正在引用该文件:';
+$lang['ref_hidden']  = '页面上的有些内容或许超出了您的阅读权限';
+
 $lang['hits']       = '个符合';
 $lang['quickhits']  = '符合的页面名称';
 $lang['toc']        = '本页目录';
@@ -70,6 +113,7 @@ $lang['diff']       = '显示跟目前版本的差异';
 $lang['line']       = '行';
 $lang['breadcrumb'] = '目前的足迹';
 $lang['lastmod']    = '上一次变更';
+$lang['by']         = '通过';
 $lang['deleted']    = '移除';
 $lang['created']    = '建立';
 $lang['restored']   = '已恢复为旧版';
@@ -85,6 +129,7 @@ $lang['qb_bold']    = '粗体';
 $lang['qb_italic']  = '斜体';
 $lang['qb_underl']  = '底线';
 $lang['qb_code']    = '程式码';
+$lang['qb_strike']  = '划线文字';
 $lang['qb_h1']      = 'H1 标题';
 $lang['qb_h2']      = 'H2 标题';
 $lang['qb_h3']      = 'H3 标题';
@@ -97,6 +142,9 @@ $lang['qb_ol']      = '项目表(数字)';
 $lang['qb_ul']      = '项目表(符号)';
 $lang['qb_media']   = '加入图片或档案';
 $lang['qb_sig']     = '插入签名';
+$lang['qb_smileys'] = '表情符号';
+$lang['qb_chars']   = '特殊字符';
+
 
 // no official language strings
 $lang['txt_insert']    = '放入日历';
