@@ -1,7 +1,7 @@
 <?php
 /**
  * Utilities for handling pagenames
- * 
+ *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author     Andreas Gohr <andi@splitbrain.org>
  * @todo       Combine similar functions like {wiki,media,meta}FN()
@@ -13,24 +13,25 @@
  * Uses either standard $_REQUEST variable or extracts it from
  * the full request URI when userewrite is set to 2
  *
- * For $param='id' $conf['start'] is returned if no id was found
- * and the returned ID will be cleaned. For other params the
- * cleaning has to be done outside this function
- * 
+ * For $param='id' $conf['start'] is returned if no id was found.
+ * If the second parameter is true (default) the ID is cleaned.
+ *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function getID($param='id'){
+function getID($param='id',$clean=true){
   global $conf;
 
   $id = $_REQUEST[$param];
 
-  if($param == 'id') $id = cleanID($id);
-  
   //construct page id from request URI
   if(empty($id) && $conf['userewrite'] == 2){
     //get the script URL
     if($conf['basedir']){
-      $script = $conf['basedir'].basename($_SERVER['SCRIPT_FILENAME']);
+      $relpath = '';
+      if($param != 'id') {
+        $relpath = 'lib/exe/';
+      }
+      $script = $conf['basedir'].$relpath.basename($_SERVER['SCRIPT_FILENAME']);
     }elseif($_SERVER['DOCUMENT_ROOT'] && $_SERVER['SCRIPT_FILENAME']){
       $script = preg_replace ('/^'.preg_quote($_SERVER['DOCUMENT_ROOT'],'/').'/','',
                               $_SERVER['SCRIPT_FILENAME']);
@@ -48,8 +49,10 @@ function getID($param='id'){
       $id = preg_replace ('/\?.*/','',$match[1]);
     }
     $id = urldecode($id);
-    $id = cleanID($id);
+    //strip leading slashes
+    $id = preg_replace('!^/+!','',$id);
   }
+  if($clean) $id = cleanID($id);
   if(empty($id) && $param=='id') $id = $conf['start'];
 
   return $id;
@@ -62,12 +65,14 @@ function getID($param='id'){
  * converted to unaccented ones
  *
  * @author Andreas Gohr <andi@splitbrain.org>
+ * @param  string  $id    The pageid to clean
+ * @param  boolean $ascii Force ASCII
  */
-function cleanID($id){
+function cleanID($id,$ascii=false){
   global $conf;
   global $lang;
   static $sepcharpat = null;
-  
+
   $sepchar = $conf['sepchar'];
   if($sepcharpat == null) // build string only once to save clock cycles
     $sepcharpat = '#\\'.$sepchar.'+#';
@@ -83,10 +88,13 @@ function cleanID($id){
     $id = strtr($id,'/',$sepchar);
   }
 
-  if($conf['deaccent']) $id = utf8_deaccent($id,-1);
+  if($conf['deaccent'] == 2 || $ascii) $id = utf8_romanize($id);
+  if($conf['deaccent'] || $ascii) $id = utf8_deaccent($id,-1);
 
   //remove specials
-  $id = utf8_stripspecials($id,$sepchar);
+  $id = utf8_stripspecials($id,$sepchar,'\*');
+
+  if($ascii) $id = utf8_strip($id);
 
   //clean up
   $id = preg_replace($sepcharpat,$sepchar,$id);
@@ -298,4 +306,28 @@ function getCacheName($data,$ext=''){
   return $file;
 }
 
+/**
+ * Checks a pageid against $conf['hidepages']
+ *
+ * @author Andreas Gohr <gohr@cosmocode.de>
+ */
+function isHiddenPage($id){
+  global $conf;
+  if(empty($conf['hidepages'])) return false;
+
+  if(preg_match('/'.$conf['hidepages'].'/ui',':'.$id)){
+    return true;
+  }
+  return false;
+}
+
+/**
+ * Reverse of isHiddenPage
+ *
+ * @author Andreas Gohr <gohr@cosmocode.de>
+ */
+function isVisiblePage($id){
+  return !isHiddenPage($id);
+}
+
 //Setup VIM: ex: et ts=2 enc=utf-8 :
