@@ -112,14 +112,20 @@ function tpl_content(){
     case 'register':
       html_register();
       break;
+    case 'resendpwd':
+      html_resendpwd();
+      break;
     case 'denied':
       print p_locale_xhtml('denied');
-			break;
+      break;
+    case 'profile' :
+      html_updateprofile();
+      break;
     case 'admin':
       tpl_admin();
       break;
     default:
-			msg("Failed to handle command: ".hsc($ACT),-1); 
+            msg("Failed to handle command: ".hsc($ACT),-1);
   }
 }
 
@@ -145,19 +151,6 @@ function tpl_admin(){
         $plugin->html();
     else
         html_admin();
-/*
-  switch($_REQUEST['page']){
-        case 'acl':
-            admin_acl_html();
-            break;
-        case 'plugin':
-            require_once(DOKU_INC.'inc/admin_plugin.php');
-            admin_plugin_html();
-            break;
-    default:
-            html_admin();
-    }
-*/    
 }
 
 /**
@@ -165,9 +158,10 @@ function tpl_admin(){
  *
  * This has to go into the head section of your template.
  *
+ * @param  boolean $alt Should feeds and alternative format links be added?
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function tpl_metaheaders(){
+function tpl_metaheaders($alt=true){
   global $ID;
   global $INFO;
   global $ACT;
@@ -179,14 +173,16 @@ function tpl_metaheaders(){
   ptln('<meta name="generator" content="DokuWiki '.getVersion().'" />',$it);
   ptln('<link rel="start" href="'.DOKU_BASE.'" />',$it);
   ptln('<link rel="contents" href="'.wl($ID,'do=index').'" title="'.$lang['index'].'" />',$it);
-  ptln('<link rel="alternate" type="application/rss+xml" title="Recent Changes" href="'.DOKU_BASE.'feed.php" />',$it);
-  ptln('<link rel="alternate" type="application/rss+xml" title="Current Namespace" href="'.DOKU_BASE.'feed.php?mode=list&amp;ns='.$INFO['namespace'].'" />',$it);
-  ptln('<link rel="alternate" type="text/html" title="Plain HTML" href="'.wl($ID,'do=export_html').'" />',$it);
-  ptln('<link rel="alternate" type="text/plain" title="Wiki Markup" href="'.wl($ID, 'do=export_raw').'" />',$it);
-  ptln('<link rel="stylesheet" media="screen" type="text/css" href="'.DOKU_BASE.'lib/styles/style.css" />',$it);
+
+  if($alt){
+    ptln('<link rel="alternate" type="application/rss+xml" title="Recent Changes" href="'.DOKU_BASE.'feed.php" />',$it);
+    ptln('<link rel="alternate" type="application/rss+xml" title="Current Namespace" href="'.DOKU_BASE.'feed.php?mode=list&amp;ns='.$INFO['namespace'].'" />',$it);
+    ptln('<link rel="alternate" type="text/html" title="Plain HTML" href="'.wl($ID,'do=export_xhtml').'" />',$it);
+    ptln('<link rel="alternate" type="text/plain" title="Wiki Markup" href="'.wl($ID, 'do=export_raw').'" />',$it);
+  }
 
   // setup robot tags apropriate for different modes
-  if( ($ACT=='show' || $ACT=='export_html') && !$REV){
+  if( ($ACT=='show' || $ACT=='export_xhtml') && !$REV){
     if($INFO['exists']){
       ptln('<meta name="date" content="'.date('Y-m-d\TH:i:sO',$INFO['lastmod']).'" />',$it);
       //delay indexing:
@@ -202,47 +198,35 @@ function tpl_metaheaders(){
     ptln('<meta name="robots" content="noindex,nofollow" />',$it);
   }
 
-  // include some JavaScript language strings
-  ptln('<script language="javascript" type="text/javascript" charset="utf-8">',$it);
-  ptln("  var alertText   = '".str_replace('\\\\n','\\n',addslashes($lang['qb_alert']))."'",$it);
-  ptln("  var notSavedYet = '".str_replace('\\\\n','\\n',addslashes($lang['notsavedyet']))."'",$it);
-  ptln("  var DOKU_BASE   = '".DOKU_BASE."'",$it);
-  ptln('</script>',$it);
- 
-  // load the default JavaScript files
-  ptln('<script language="javascript" type="text/javascript" charset="utf-8" src="'.
-       DOKU_BASE.'lib/scripts/script.js"></script>',$it);
-  ptln('<script language="javascript" type="text/javascript" charset="utf-8" src="'.
-       DOKU_BASE.'lib/scripts/tw-sack.js"></script>',$it);
-  ptln('<script language="javascript" type="text/javascript" charset="utf-8" src="'.
-       DOKU_BASE.'lib/scripts/ajax.js"></script>',$it);
+  // load stylesheets
+  ptln('<link rel="stylesheet" media="screen" type="text/css" href="'.DOKU_BASE.'lib/exe/css.php" />',$it);
+  ptln('<link rel="stylesheet" media="print" type="text/css" href="'.DOKU_BASE.'lib/exe/css.php?print=1" />',$it);
 
-  // load spellchecker script if wanted
-  if($conf['spellchecker'] && ($ACT=='edit' || $ACT=='preview')){
-    ptln('<script language="javascript" type="text/javascript" charset="utf-8" src="'.
-       DOKU_BASE.'lib/scripts/spellcheck.js"></script>',$it);
+  // load javascript
+  $js_edit  = ($ACT=='edit' || $ACT=='preview') ? 1 : 0;
+  $js_write = ($INFO['writable']) ? 1 : 0;
+  if($js_edit && $js_write){
+    ptln('<script type="text/javascript" charset="utf-8">',$it);
+    ptln("NS='".$INFO['namespace']."';",$it+2);
+    if($conf['useacl'] && $_SERVER['REMOTE_USER']){
+      require_once(DOKU_INC.'inc/toolbar.php');
+      ptln("SIG='".toolbar_signature()."';",$it+2);
+    }
+    ptln('</script>',$it);
   }
-  
-  // dom tool tip library, for insitu footnotes
-  ptln('<script language="javascript" type="text/javascript" charset="utf-8" src="'.
-       DOKU_BASE.'lib/scripts/domLib.js"></script>',$it);
-  ptln('<script language="javascript" type="text/javascript" charset="utf-8" src="'.
-       DOKU_BASE.'lib/scripts/domTT.js"></script>',$it);
-
-  // plugin stylesheets and Scripts
-  plugin_printCSSJS();
+  ptln('<script type="text/javascript" charset="utf-8" src="'.
+       DOKU_BASE.'lib/exe/js.php?edit='.$js_edit.'&amp;write='.$js_write.'"></script>',$it);
 }
 
 /**
  * Print a link
  *
- * Just builds a link but adds additional JavaScript needed for
- * the unsaved data check needed in the edit form.
+ * Just builds a link.
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function tpl_link($url,$name,$more=''){
-  print '<a href="'.$url.'" onclick="return svchk()" onkeypress="return svchk()"';
+  print '<a href="'.$url.'" ';
   if ($more) print ' '.$more;
   print ">$name</a>";
 }
@@ -268,7 +252,7 @@ function tpl_pagelink($id,$name=NULL){
  */
 function tpl_getparent($ID){
   global $conf;
-    
+
   if ($ID != $conf['start']) {
     $idparts = explode(':', $ID);
     $pn = array_pop($idparts);    // get the page name
@@ -286,7 +270,7 @@ function tpl_getparent($ID){
         }
       }
     }
-    
+
     if (@file_exists(wikiFN($ID))) {
       return $ID;
     }
@@ -320,6 +304,7 @@ function tpl_button($type){
   global $NS;
   global $INFO;
   global $conf;
+  global $auth;
 
   switch($type){
     case 'edit':
@@ -335,8 +320,8 @@ function tpl_button($type){
       print html_btn('index',$ID,'x',array('do' => 'index'));
       break;
     case 'back':
-      if ($ID = tpl_getparent($ID)) {
-        print html_btn('back',$ID,'b',array('do' => 'show'));
+      if ($parent = tpl_getparent($ID)) {
+        print html_btn('back',$parent,'b',array('do' => 'show'));
       }
       break;
     case 'top':
@@ -372,6 +357,12 @@ function tpl_button($type){
     case 'backlink':
       print html_btn('backlink',$ID,'',array('do' => 'backlink'));
       break;
+    case 'profile':
+      if($conf['useacl'] && $_SERVER['REMOTE_USER'] &&
+         $auth->canDo('Profile') && ($ACT!='profile')){
+        print html_btn('profile',$ID,'',array('do' => 'profile'));
+      }
+      break;
     default:
       print '[unknown button type]';
   }
@@ -403,6 +394,7 @@ function tpl_actionlink($type,$pre='',$suf=''){
   global $ACT;
   global $conf;
   global $lang;
+  global $auth;
 
   switch($type){
     case 'edit':
@@ -439,7 +431,7 @@ function tpl_actionlink($type,$pre='',$suf=''){
       tpl_link(wl($ID,'do=index'),$pre.$lang['btn_index'].$suf,'class="action index" accesskey="x"');
       break;
     case 'top':
-      print '<a href="#top" class="action top" accesskey="x">'.$pre.$lang['btn_top'].$suf.'</a>';
+      print '<a href="#dokuwiki__top" class="action top" accesskey="x">'.$pre.$lang['btn_top'].$suf.'</a>';
       break;
     case 'back':
       if ($ID = tpl_getparent($ID)) {
@@ -460,9 +452,10 @@ function tpl_actionlink($type,$pre='',$suf=''){
         tpl_link(wl($ID,'do=admin'),$pre.$lang['btn_admin'].$suf,'class="action admin"');
       break;
    case 'subscribe':
+   case 'subscription':
       if($conf['useacl'] && $ACT == 'show' && $conf['subscribers'] == 1){
         if($_SERVER['REMOTE_USER']){
-          if($info['subscribed']) {
+          if($INFO['subscribed']) {
             tpl_link(wl($ID,'do=unsubscribe'),$pre.$lang['btn_unsubscribe'].$suf,'class="action unsubscribe"');
           } else {
             tpl_link(wl($ID,'do=subscribe'),$pre.$lang['btn_subscribe'].$suf,'class="action subscribe"');
@@ -470,9 +463,15 @@ function tpl_actionlink($type,$pre='',$suf=''){
         }
       }
       break;
-	case 'backlink':
-	  tpl_link(wl($ID,'do=backlink'),$pre.$lang['btn_backlink'].$suf, 'class="action backlink"');
-	  break;
+    case 'backlink':
+      tpl_link(wl($ID,'do=backlink'),$pre.$lang['btn_backlink'].$suf, 'class="action backlink"');
+      break;
+    case 'profile':
+      if($conf['useacl'] && $_SERVER['REMOTE_USER'] &&
+         $auth->canDo('Profile') && ($ACT!='profile')){
+        tpl_link(wl($ID,'do=profile'),$pre.$lang['btn_profile'].$suf, 'class="action profile"');
+      }
+      break;
     default:
       print '[unknown link type]';
   }
@@ -481,23 +480,28 @@ function tpl_actionlink($type,$pre='',$suf=''){
 /**
  * Print the search form
  *
+ * If the first parameter is given a div with the ID 'qsearch_out' will
+ * be added which instructs the ajax pagequicksearch to kick in and place
+ * its output into this div. The second parameter controls the propritary
+ * attribute autocomplete. If set to false this attribute will be set with an
+ * value of "off" to instruct the browser to disable it's own built in
+ * autocompletion feature (MSIE and Firefox)
+ *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function tpl_searchform(){
+function tpl_searchform($ajax=true,$autocomplete=true){
   global $lang;
   global $ACT;
-  
-  print '<form action="'.wl().'" accept-charset="utf-8" class="search" name="search" onsubmit="return svchk()">';
+
+  print '<form action="'.wl().'" accept-charset="utf-8" class="search" id="dw__search"><div class="no">';
   print '<input type="hidden" name="do" value="search" />';
   print '<input type="text" ';
-  
-  if ($ACT == 'search')
-    print 'value="'.$_REQUEST['id'].'" '; /* keep search input as long as user stays on search page */
-    
-  print 'id="qsearch_in" accesskey="f" name="id" class="edit" onkeyup="ajax_qsearch.call(\'qsearch_in\',\'qsearch_out\')" />';
+  if($ACT == 'search') print 'value="'.htmlspecialchars($_REQUEST['id']).'" ';
+  if(!$autocomplete) print 'autocomplete="off" ';
+  print 'id="qsearch__in" accesskey="f" name="id" class="edit" />';
   print '<input type="submit" value="'.$lang['btn_search'].'" class="button" />';
-  print '<div id="qsearch_out" class="ajax_qsearch" onclick="this.style.display=\'none\'"></div>';
-  print '</form>';
+  if($ajax) print '<div id="qsearch__out" class="ajax_qsearch JSpopup"></div>';
+  print '</div></form>';
 }
 
 /**
@@ -533,12 +537,12 @@ function tpl_breadcrumbs(){
 /**
  * Hierarchical breadcrumbs
  *
- * This code was suggested as replacement for the usual breadcrumbs
- * trail in the Wiki and was modified by me.
+ * This code was suggested as replacement for the usual breadcrumbs.
  * It only makes sense with a deep site structure.
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  * @author Nigel McNie <oracle.shinoda@gmail.com>
+ * @author Sean Coates <sean@caedmon.net>
  * @link   http://wiki.splitbrain.org/wiki:tipsandtricks:hierarchicalbreadcrumbs
  * @todo   May behave strangely in RTL languages
  */
@@ -547,16 +551,22 @@ function tpl_youarehere(){
   global $ID;
   global $lang;
 
+  //check if enabled
+  if(!$conf['youarehere']) return;
 
   $parts     = explode(':', $ID);
 
-  // Perhaps a $lang['tree'] could be defined? "Trace" isn't too appropriate
-  //print $lang['tree'].': ';
-  print $lang['breadcrumb'].': ';
+  print $lang['youarehere'].': ';
 
   //always print the startpage
-  if( $a_part[0] != $conf['start'] )
-    tpl_link(wl($conf['start']),$conf['start'],'title="'.$conf['start'].'"');
+  if( $a_part[0] != $conf['start']){
+    if($conf['useheading']){
+      $pageName = p_get_first_heading($conf['start']);
+    }else{
+      $pageName = $conf['start'];
+    }
+    tpl_link(wl($conf['start']),$pageName,'title="'.$pageName.'"');
+  }
 
   $page = '';
   foreach ($parts as $part){
@@ -567,7 +577,14 @@ function tpl_youarehere(){
     $page .= $part;
 
     if(file_exists(wikiFN($page))){
-      tpl_link(wl($page),$part,'title="'.$page.'"');
+      if($conf['useheading']){
+        $pageName = p_get_first_heading($page);
+        $partName = $pageName;
+      }else{
+        $pageName = $page;
+        $partName = $part;
+      }
+      tpl_link(wl($page),$partName,'title="'.$pageName.'"');
     }else{
       // Print the link, but mark as not-existing, as for other non-existing links
       tpl_link(wl($page),$part,'title="'.$page.'" class="wikilink2"');
@@ -642,7 +659,7 @@ function tpl_pageinfo(){
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function tpl_medianamespaces(){
-	global $conf;
+    global $conf;
 
   $data = array();
   search($data,$conf['mediadir'],'search_namespaces',array());
@@ -671,34 +688,41 @@ function tpl_mediafilelist(){
 
   ptln('<ul>',2);
   foreach($data as $item){
-    ptln('<li>',4);
-    ptln('<a href="javascript:mediaSelect(\''.$item['id'].'\')">'.
+    if(!$item['isimg']){
+      // add file icons
+      list($ext,$mime) = mimetype($item['file']);
+      $class = preg_replace('/[^_\-a-z0-9]+/i','_',$ext);
+      $class = ' class="mediafile mf_'.$class.'"';
+    }
+
+    ptln('<li><div class="li">',4);
+    ptln('<a href="javascript:mediaSelect(\':'.$item['id'].'\')"'.$class.'>'.
          utf8_decodeFN($item['file']).
          '</a>',6);
 
     //prepare deletion button
     if($AUTH >= AUTH_DELETE){
-      $ask  = $lang['del_confirm'].'\\n';
-      $ask .= $item['id'];
+      $ask  = addslashes($lang['del_confirm']).'\\n';
+      $ask .= addslashes($item['id']);
 
-      $del = '<a href="'.DOKU_BASE.'lib/exe/media.php?delete='.urlencode($item['id']).'" '.
+      $del = '<a href="'.DOKU_BASE.'lib/exe/media.php?delete='.rawurlencode($item['id']).'" '.
              'onclick="return confirm(\''.$ask.'\')" onkeypress="return confirm(\''.$ask.'\')">'.
              '<img src="'.DOKU_BASE.'lib/images/del.png" alt="'.$lang['btn_delete'].'" '.
-             'align="bottom" title="'.$lang['btn_delete'].'" /></a>';
+             'title="'.$lang['btn_delete'].'" /></a>';
     }else{
       $del = '';
     }
 
     if($item['isimg']){
-      $w = $item['meta']->getField('File.Width');
-      $h = $item['meta']->getField('File.Height');
+      $w = (int) $item['meta']->getField('File.Width');
+      $h = (int) $item['meta']->getField('File.Height');
 
       ptln('('.$w.'&#215;'.$h.' '.filesize_h($item['size']).')',6);
       ptln($del.'<br />',6);
       ptln('<div class="imagemeta">',6);
-      
+
       //build thumbnail
-      print '<a href="javascript:mediaSelect(\''.$item['id'].'\')">';
+      print '<a href="javascript:mediaSelect(\':'.$item['id'].'\')">';
 
       if($w>120 || $h>120){
         $ratio = $item['meta']->getResizeRatio(120);
@@ -717,22 +741,22 @@ function tpl_mediafilelist(){
 
       print '<img src="'.$src.'" '.$att.' />';
       print '</a>';
-      
+
       //read EXIF/IPTC data
       $t = $item['meta']->getField('IPTC.Headline');
-      if($t) print '<b>'.$t.'</b><br />';
+      if($t) print '<strong>'.htmlspecialchars($t).'</strong><br />';
 
       $t = $item['meta']->getField(array('IPTC.Caption','EXIF.UserComment',
                                          'EXIF.TIFFImageDescription',
                                          'EXIF.TIFFUserComment'));
-      if($t) print $t.'<br />';
+      if($t) print htmlspecialchars($t).'<br />';
 
       $t = $item['meta']->getField(array('IPTC.Keywords','IPTC.Category'));
-      if($t) print '<i>'.$t.'</i><br />';
+      if($t) print '<em>'.htmlspecialchars($t).'</em><br />';
 
       //add edit button
       if($AUTH >= AUTH_UPLOAD && $item['meta']->getField('File.Mime') == 'image/jpeg'){
-        print '<a href="'.DOKU_BASE.'lib/exe/media.php?edit='.urlencode($item['id']).'">';
+        print '<a href="'.DOKU_BASE.'lib/exe/media.php?edit='.rawurlencode($item['id']).'">';
         print '<img src="'.DOKU_BASE.'lib/images/edit.gif" alt="'.$lang['metaedit'].'" title="'.$lang['metaedit'].'" />';
         print '</a>';
       }
@@ -742,7 +766,7 @@ function tpl_mediafilelist(){
       ptln ('('.filesize_h($item['size']).')',6);
       ptln($del,6);
     }
-    ptln('</li>',4);
+    ptln('</div></li>',4);
   }
   ptln('</ul>',2);
 }
@@ -758,7 +782,7 @@ function tpl_showreferences(&$data){
   global $lang;
 
   $hidden=0; //count of hits without read permission
-  
+
   if(count($data)){
     usort($data,'sort_search_fulltext');
     foreach($data as $row){
@@ -790,7 +814,7 @@ function tpl_mediauploadform(){
 
   if(!$UPLOADOK) return;
 
-  ptln('<form action="'.DOKU_BASE.'lib/exe/media.php" name="upload"'.
+  ptln('<form action="'.DOKU_BASE.'lib/exe/media.php" id="dw__upload"'.
        ' method="post" enctype="multipart/form-data">',2);
   ptln($lang['txt_upload'].':<br />',4);
   ptln('<input type="file" name="upload" class="edit" onchange="suggestWikiname();" />',4);
@@ -799,7 +823,7 @@ function tpl_mediauploadform(){
   ptln('<input type="text" name="id" class="edit" />',4);
   ptln('<input type="submit" class="button" value="'.$lang['btn_upload'].'" accesskey="s" />',4);
   if($AUTH >= AUTH_DELETE){
-    ptln('<label for="ow" class="simple"><input type="checkbox" name="ow" value="1" id="ow">'.$lang['txt_overwrt'].'</label>',4);
+    ptln('<label for="dw__ow"><input type="checkbox" name="ow" value="1" id="dw__ow" />'.$lang['txt_overwrt'].'</label>',4);
   }
   ptln('</form>',2);
 }
@@ -917,8 +941,10 @@ function tpl_indexerWebBug(){
   global $INFO;
   if(!$INFO['exists']) return;
 
+  if(isHiddenPage($ID)) return; //no need to index hidden pages
+
   $p = array();
-  $p['src']    = DOKU_BASE.'lib/exe/indexer.php?id='.urlencode($ID).
+  $p['src']    = DOKU_BASE.'lib/exe/indexer.php?id='.rawurlencode($ID).
                  '&'.time();
   $p['width']  = 1;
   $p['height'] = 1;
