@@ -16,22 +16,13 @@
 ?>
 <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo $conf['lang']?>" lang="<?php echo $conf['lang']?>" dir="ltr">
 <head>
-  <title><?php echo hsc($lang['mediaselect'])?> [<?php echo hsc($conf['title'])?>]</title>
   <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
+  <title><?php echo hsc($lang['mediaselect'])?> [<?php echo hsc($conf['title'])?>]</title>
 
   <?php tpl_metaheaders()?>
 
-  <link rel="shortcut icon" href="<?php echo DOKU_BASE?>images/favicon.ico" />
-  <link rel="stylesheet" media="screen" type="text/css" href="<?php echo DOKU_TPL?>layout.css" />
-  <link rel="stylesheet" media="screen" type="text/css" href="<?php echo DOKU_TPL?>design.css" />
+  <link rel="shortcut icon" href="<?php echo DOKU_TPL?>images/favicon.ico" />
 
-  <!--[if gte IE 5]>
-  <style type="text/css">
-    /* that IE 5+ conditional comment makes this only visible in IE 5+ */
-    /* IE bugfix for transparent PNGs */
-    //img { behavior: url("<?php echo DOKU_BASE?>/pngbehavior.htc"); }
-  </style>
-  <![endif]-->
 </head>
 
 <body>
@@ -44,11 +35,11 @@
     <div class="mediaref_head">
       <p><?php echo hsc($lang['ref_inuse'])?></p>
     </div>
-  
+
     <?php tpl_showreferences($mediareferences)?>
-	
-	<div class="mediaref_footer">
-	  <hr>
+
+  <div class="mediaref_footer">
+    <hr />
       <?php tpl_button('backtomedia')?>
     </div>
   </div>
